@@ -1,27 +1,19 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
-from datetime import datetime
-from simba.read_config_unit_tests import (read_config_entry,
-                                          read_config_file,
-                                          check_if_filepath_list_is_empty,
-                                          read_project_path_and_file_type)
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
-from simba.misc_tools import (check_multi_animal_status,
-                              line_length_numba,
-                              SimbaTimer)
-from simba.drop_bp_cords import (create_body_part_dictionary,
-                                 getBpNames,
-                                 get_fn_ext,
+from simba.read_config_unit_tests import check_if_filepath_list_is_empty
+from simba.feature_extractors.unit_tests import read_video_info
+from simba.misc_tools import line_length_numba, SimbaTimer
+from simba.drop_bp_cords import (get_fn_ext,
                                  checkDirectionalityCords)
 from simba.rw_dfs import read_df
-from simba.enums import ReadConfig, Paths, Dtypes
 import pandas as pd
-
+from simba.mixins.config_reader import ConfigReader
+from simba.utils.errors import AnimalNumberError
 import itertools
 import numpy as np
-import os, glob
+import os
 
-class DirectingOtherAnimalsAnalyzer(object):
+class DirectingOtherAnimalsAnalyzer(ConfigReader):
     """
     Class for calculating when animals are directing towards body-parts of other animals. Results are stored in
     the `project_folder/logs/directionality_dataframes` directory of the SimBA project
@@ -33,8 +25,10 @@ class DirectingOtherAnimalsAnalyzer(object):
 
     Notes
     -----
-    Requires the pose-estimation data for the ``left ear``, ``right ear`` and ``nose`` of
-    each individual animals. `GitHub documentation <https://github.com/sgoldenlab/simba/blob/master/docs/ROI_tutorial.md#part-3-generating-features-from-roi-data>`__.
+    Requires the pose-estimation data for the ``left ear``, ``right ear`` and ``nose`` of each individual animals.
+    `GitHub documentation <https://github.com/sgoldenlab/simba/blob/master/docs/ROI_tutorial.md#part-3-generating-features-from-roi-data>`__.
+    `Expected output <https://github.com/sgoldenlab/simba/blob/master/misc/Direction_data_example.csv>`__.
+
 
     Examples
     -----
@@ -48,29 +42,14 @@ class DirectingOtherAnimalsAnalyzer(object):
     def __init__(self,
                  config_path: str):
 
-        self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
-        self.config = read_config_file(config_path)
-
-        self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
-        self.animal_cnt = read_config_entry(self.config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.ANIMAL_CNT.value, Dtypes.INT.value)
+        super().__init__(config_path=config_path)
         if self.animal_cnt < 2:
-            print('SIMBA ERROR: Cannot analyze directionality between animals in a 1 animal project.')
-            raise ValueError('SIMBA ERROR: Cannot analyze directionality between animals in a 1 animal project.')
-        self.logs_dir = os.path.join(self.project_path, 'logs')
-        self.data_in_dir = os.path.join(self.project_path, Paths.OUTLIER_CORRECTED.value)
-        self.data_out_dir = os.path.join(self.project_path , Paths.DIRECTIONALITY_DF_DIR.value)
-        if not os.path.exists(self.data_out_dir): os.makedirs(self.data_out_dir)
-        self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, Paths.VIDEO_INFO.value))
-        self.multi_animal_status, self.multi_animal_id_lst = check_multi_animal_status(self.config, self.animal_cnt)
-        self.x_cols, self.y_cols, self.p_cols = getBpNames(config_path)
-        self.animal_bp_dict = create_body_part_dictionary(self.multi_animal_status, self.multi_animal_id_lst, self.animal_cnt, self.x_cols, self.y_cols, [], [])
+            raise AnimalNumberError('Cannot analyze directionality between animals in a 1 animal project.')
+        if not os.path.exists(self.directionality_df_dir): os.makedirs(self.directionality_df_dir)
+        check_if_filepath_list_is_empty(filepaths=self.outlier_corrected_paths,
+                                        error_msg=f'SIMBA ERROR: No data found in the {self.outlier_corrected_dir} directory')
         self.animal_permutations = list(itertools.permutations(self.animal_bp_dict, 2))
-        self.files_found = glob.glob(self.data_in_dir + '/*.' + self.file_type)
-        check_if_filepath_list_is_empty(filepaths=self.files_found,
-                                        error_msg='SIMBA ERROR: No data found in the {} directory'.format(self.data_in_dir))
-        self.session_timer = SimbaTimer()
-        self.session_timer.start_timer()
-        print('Processing {} video(s)...'.format(str(len(self.files_found))))
+        print(f'Processing {str(len(self.outlier_corrected_paths))} video(s)...')
 
     def process_directionality(self):
         """
@@ -83,7 +62,7 @@ class DirectingOtherAnimalsAnalyzer(object):
         """
 
         self.results_dict = {}
-        for file_cnt, file_path in enumerate(self.files_found):
+        for file_cnt, file_path in enumerate(self.outlier_corrected_paths):
             video_timer = SimbaTimer()
             video_timer.start_timer()
             _, video_name, _ = get_fn_ext(file_path)
@@ -116,7 +95,7 @@ class DirectingOtherAnimalsAnalyzer(object):
                     bp_data.insert(loc=0, column='Animal_1', value=animal_permutation[0])
                     self.results_dict[video_name]['{} {} {}'.format(animal_permutation[0], 'directing towards', animal_permutation[1])][x_bp[:-2]] = bp_data
             video_timer.stop_timer()
-            print('Direction analysis complete for video {} ({}/{}, elapsed time: {}s)...'.format(video_name, str(file_cnt + 1), str(len(self.files_found)), video_timer.elapsed_time_str))
+            print('Direction analysis complete for video {} ({}/{}, elapsed time: {}s)...'.format(video_name, str(file_cnt + 1), str(len(self.outlier_corrected_paths)), video_timer.elapsed_time_str))
 
     def create_directionality_dfs(self):
         """
@@ -155,10 +134,10 @@ class DirectingOtherAnimalsAnalyzer(object):
 
 
         for video_name, video_data in self.directionality_df_dict.items():
-            save_name = os.path.join(self.data_out_dir, video_name + '.csv')
+            save_name = os.path.join(self.directionality_df_dir, video_name + '.csv')
             video_data.to_csv(save_name)
-            print('Detailed directional data saved for video {} ...'.format(str(video_name)))
-        print('All detailed directional data saved in the {} directory'.format(str(self.data_out_dir)))
+            print(f'Detailed directional data saved for video {video_name}...')
+        print(f'All detailed directional data saved in the {self.directionality_df_dir} directory')
 
     def summary_statistics(self):
 
@@ -174,7 +153,7 @@ class DirectingOtherAnimalsAnalyzer(object):
         print('Computing summary statistics...')
         out_df_lst = []
         for video_name, video_data in self.results_dict.items():
-            _, _, fps = read_video_info(self.vid_info_df, video_name)
+            _, _, fps = read_video_info(self.video_info_df, video_name)
             for animal_permutation, permutation_data in video_data.items():
                 idx_directing = set()
                 for bp_name, bp_data in permutation_data.items():
@@ -182,11 +161,11 @@ class DirectingOtherAnimalsAnalyzer(object):
                 value = round(len(idx_directing) / fps, 3)
                 out_df_lst.append(pd.DataFrame([[video_name, animal_permutation, value]], columns=['Video', 'Animal permutation', 'Value (s)']))
         self.summary_df = pd.concat(out_df_lst, axis=0).sort_values(by=['Video', 'Animal permutation']).set_index('Video')
-        self.save_path = os.path.join(self.logs_dir, 'Direction_data_{}{}'.format(str(self.datetime), '.csv'))
+        self.save_path = os.path.join(self.logs_path, 'Direction_data_{}{}'.format(str(self.datetime), '.csv'))
         self.summary_df.to_csv(self.save_path)
-        self.session_timer.stop_timer()
-        print('Summary directional statistics saved at ' + os.path.join(self.logs_dir, 'Direction_data_{}{}'.format(str(self.datetime), '.csv')))
-        print('SIMBA COMPLETE: All directional data saved in SimBA project (elapsed time: {}s).'.format(self.session_timer.elapsed_time_str))
+        self.timer.stop_timer()
+        print('Summary directional statistics saved at ' + os.path.join(self.logs_path, 'Direction_data_{}{}'.format(str(self.datetime), '.csv')))
+        print('SIMBA COMPLETE: All directional data saved in SimBA project (elapsed time: {}s).'.format(self.timer.elapsed_time_str))
 
 # test = DirectingOtherAnimalsAnalyzer(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/project_config.ini')
 # test.process_directionality()
