@@ -1,24 +1,22 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
-from simba.read_config_unit_tests import (check_int,
-                                          check_str,
-                                          check_float,
-                                          read_config_entry,
+from simba.read_config_unit_tests import (read_config_entry,
                                           read_config_file,
                                           check_if_filepath_list_is_empty)
 import os, glob
 import pandas as pd
 from datetime import datetime
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
+from simba.feature_extractors.unit_tests import read_video_info_csv, read_video_info
 from simba.drop_bp_cords import get_fn_ext
 from simba.rw_dfs import read_df
 from simba.misc_tools import (detect_bouts,
                               SimbaTimer)
 from simba.enums import Paths, ReadConfig
+from simba.mixins.config_reader import ConfigReader
 import itertools
 import seaborn as sns
 
-class FSTTCPerformer(object):
+class FSTTCPerformer(ConfigReader):
     """
     Class for calculating forward spike-time tiling coefficients between pairs of
     classified behaviors.
@@ -62,23 +60,15 @@ class FSTTCPerformer(object):
                  behavior_lst: list,
                  create_graphs: bool):
 
-        self.timer = SimbaTimer()
-        self.timer.start_timer()
+        super().__init__(config_path=config_path)
+
         self.time_delta = int(time_window)
         self.behavior_lst = behavior_lst
         self.graph_status = create_graphs
-        self.config = read_config_file(config_path)
-        self.project_path = read_config_entry(self.config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value, data_type=ReadConfig.FOLDER_PATH.value)
-        self.in_path = os.path.join(self.project_path, Paths.MACHINE_RESULTS_DIR.value)
-        self.logs_folder = os.path.join(self.project_path, 'logs')
-        self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
-        self.file_type = read_config_entry(self.config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.FILE_TYPE.value, 'str', 'csv')
-        self.video_info_df = read_video_info_csv(os.path.join(self.project_path, Paths.VIDEO_INFO.value))
-        self.files_found = glob.glob(self.in_path + "/*." + self.file_type)
-        check_if_filepath_list_is_empty(filepaths=self.files_found,
-                                        error_msg='SIMBA ERROR: Cannot calculate FSTTC, no data found in {} directory'.format(self.in_path))
+        check_if_filepath_list_is_empty(filepaths=self.machine_results_paths,
+                                        error_msg=f'SIMBA ERROR: Cannot calculate FSTTC, no data found in {self.machine_results_paths} directory')
         self.clf_permutations = list(itertools.permutations(self.behavior_lst, 2))
-        print('Processing FSTTC for {} file(s)...'.format(str(len(self.files_found))))
+        print(f'Processing FSTTC for {str(len(self.machine_results_paths))} file(s)...')
 
     def find_sequences(self):
         """
@@ -101,10 +91,10 @@ class FSTTCPerformer(object):
                          'Difference: first behavior start to second behavior start',
                          'Time 2nd behaviour start to time window end']
 
-        for file_cnt, file_path in enumerate(self.files_found):
+        for file_cnt, file_path in enumerate(self.machine_results_paths):
             _, self.video_name, _ = get_fn_ext(file_path)
             self.video_sequence_dict[self.video_name] = {}
-            print('Analyzing behavioral sequences: {}. Video {}/{}'.format(self.video_name, str(file_cnt + 1), str(len(self.files_found))))
+            print('Analyzing behavioral sequences: {}. Video {}/{}'.format(self.video_name, str(file_cnt + 1), str(len(self.machine_results_paths))))
             _, _, self.fps = read_video_info(self.video_info_df, self.video_name)
             self.video_sequence_dict[self.video_name]['fps'] = self.fps
             self.frames_in_window = int((self.fps / 1000) * self.time_delta)
@@ -194,14 +184,12 @@ class FSTTCPerformer(object):
         None
         """
 
-
-
         self.out_df = pd.DataFrame()
         for video, data in self.results_dict.items():
             video_df = pd.DataFrame.from_dict(data, orient='index').reset_index().rename(columns={'index': 'FSTTC', 0: 'Value'})
             video_df.insert(loc=0, column='Video', value=video)
             self.out_df = pd.concat([self.out_df,video_df], axis=0)
-        file_save_path = os.path.join(self.logs_folder, 'FSTTC_{}.csv'.format(str(self.datetime)))
+        file_save_path = os.path.join(self.logs_path, 'FSTTC_{}.csv'.format(str(self.datetime)))
         self.out_df.to_csv(file_save_path)
         self.timer.stop_timer()
         print('SIMBA COMPLETE: FSTTC data saved at {} (elapsed time: {}s)'.format(file_save_path, self.timer.elapsed_time_str))
@@ -222,7 +210,7 @@ class FSTTCPerformer(object):
             figure_FSCTT = sns.violinplot(x="FSTTC", y="Value", data=data_df, cut=0)
             figure_FSCTT.set_xticklabels(figure_FSCTT.get_xticklabels(), rotation=45, size=7)
             figure_FSCTT.figure.set_size_inches(13.7, 8.27)
-            save_plot_path = os.path.join(self.logs_folder, 'FSTTC_{}.png'.format(str(self.datetime)))
+            save_plot_path = os.path.join(self.logs_path, 'FSTTC_{}.png'.format(str(self.datetime)))
             figure_FSCTT.figure.savefig(save_plot_path, bbox_inches="tight")
             print('FSTTC figure saved at {}'.format(save_plot_path))
 
@@ -234,7 +222,21 @@ class FSTTCPerformer(object):
 # test.find_sequences()
 # test.calculate_FSTTC()
 # test.save_FSTTC()
-# # test.plot_FSTTC()
+# test.plot_FSTTC()
+
+
+
+# test = FSTTCPerformer(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals/project_folder/project_config.ini',
+#                      time_window=2,
+#                      behavior_lst=['Attack', 'Sniffing'],
+#                     create_graphs=False)
+# test.find_sequences()
+# test.calculate_FSTTC()
+# test.save_FSTTC()
+# test.plot_FSTTC()
+
+
+
 # if __name__ == "__main__":
 #     config_path = r"Z:\Classifiers\100620_all\project_folder\project_config.ini"
 #     behavior_list = ['Attack', 'pursuit_prediction', 'Escape']
@@ -245,4 +247,4 @@ class FSTTCPerformer(object):
 #     FSTCC_performer.calculate_FSTTC()
 #     FSTCC_performer.save_FSTTC()
 #     # FSTCC_performer.plot_results()
-
+#
