@@ -1,26 +1,21 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
-from simba.read_config_unit_tests import (read_config_file,
-                                          check_that_column_exist,
+from simba.read_config_unit_tests import (check_that_column_exist,
                                           check_int,
                                           check_float,
-                                          read_config_entry,
-                                          check_if_filepath_list_is_empty,
-                                          read_project_path_and_file_type)
-from simba.misc_tools import SimbaTimer
-
-import os, glob
-from datetime import datetime
+                                          check_if_filepath_list_is_empty)
+import os
 from simba.rw_dfs import read_df, save_df
 from simba.drop_bp_cords import get_fn_ext
 import pandas as pd
 from simba.pybursts import kleinberg_burst_detection
-from simba.enums import ReadConfig, Paths
+from simba.enums import Paths
+from simba.mixins.config_reader import ConfigReader
 import numpy as np
 import shutil
 from copy import deepcopy
 
-class KleinbergCalculator(object):
+class KleinbergCalculator(ConfigReader):
     '''
     Class for smoothing classification results using the Kleinberg burst
     detection algorithm.
@@ -68,30 +63,21 @@ class KleinbergCalculator(object):
                  hierarchy=1,
                  hierarchical_search=False):
 
-        self.timer = SimbaTimer()
-        self.timer.start_timer()
-        self.config = read_config_file(config_path)
-
-
-        self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
-        self.in_path = os.path.join(self.project_path, Paths.MACHINE_RESULTS_DIR.value)
-        self.logs_folder = os.path.join(self.project_path, 'logs')
-        self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
+        super().__init__(config_path=config_path)
         self.hierarchical_search, sigma, gamma, hierarchy = hierarchical_search, float(sigma), float(gamma), int(hierarchy)
         check_float(value=sigma, name='sigma', min_value=1.01)
         check_float(value=gamma, name='gamma', min_value=0)
         check_int(value=hierarchy, name='hierarchy')
         self.sigma, self.gamma, self.hierarchy = float(sigma), float(gamma), float(hierarchy)
-        self.files_found = glob.glob(self.in_path + '/*.' + self.file_type)
-        check_if_filepath_list_is_empty(filepaths=self.files_found,
-                                        error_msg='SIMBA ERROR: No data files found in {}. Cannot perform Kleinberg smooting'.format(self.in_path))
+        check_if_filepath_list_is_empty(filepaths=self.machine_results_paths,
+                                        error_msg=f'SIMBA ERROR: No data files found in {self.machine_results_dir}. Cannot perform Kleinberg smooting')
         self.clfs = classifier_names
         original_data_files_folder = os.path.join(self.project_path, Paths.MACHINE_RESULTS_DIR.value, 'Pre_Kleinberg_{}'.format( self.datetime))
         if not os.path.exists(original_data_files_folder): os.makedirs(original_data_files_folder)
-        for file_path in self.files_found:
+        for file_path in self.machine_results_paths:
             _, file_name, ext = get_fn_ext(file_path)
             shutil.copyfile(file_path, os.path.join(original_data_files_folder, file_name + ext))
-        print('Processing Kleinberg burst detection for {} file(s)...'.format(str(len(self.files_found))))
+        print(f'Processing Kleinberg burst detection for {str(len(self.machine_results_paths))} file(s)...')
 
     def hierarchical_searcher(self):
         if (len(self.kleinberg_bouts['Hierarchy']) == 1) and (int(self.kleinberg_bouts.at[0, 'Hierarchy']) == 0):
@@ -133,9 +119,9 @@ class KleinbergCalculator(object):
         '''
 
         detailed_df_lst = []
-        for file_cnt, file_path in enumerate(self.files_found):
+        for file_cnt, file_path in enumerate(self.machine_results_paths):
             _, video_name, _ = get_fn_ext(file_path)
-            print('Kleinberg analysis video {}. Video {}/{}...'.format(video_name, str(file_cnt+1), str(len(self.files_found))))
+            print(f'Kleinberg analysis video {video_name}. Video { str(file_cnt+1)}/{str(len(self.machine_results_paths))}...')
             data_df = read_df(file_path, self.file_type).reset_index(drop=True)
             video_out_df = deepcopy(data_df)
             for clf in self.clfs:
@@ -162,19 +148,19 @@ class KleinbergCalculator(object):
         self.timer.stop_timer()
         if len(detailed_df_lst) > 0:
             detailed_df = pd.concat(detailed_df_lst, axis=0)
-            detailed_save_path = os.path.join(self.logs_folder, 'Kleinberg_detailed_log_{}.csv'.format(str(self.datetime)))
+            detailed_save_path = os.path.join(self.logs_path, 'Kleinberg_detailed_log_{}.csv'.format(str(self.datetime)))
             detailed_df.to_csv(detailed_save_path)
             print('SIMBA COMPLETE: Kleinberg analysis complete. See {} for details of detected bouts of all classifiers in all hierarchies (elapsed time: {}s)'.format(detailed_save_path, self.timer.elapsed_time_str))
         else:
             print('SIMBA WARNING: All behavior bouts removed following kleinberg smoothing (elapsed time: {}s).'.format(self.timer.elapsed_time_str))
 
 
-# test = KleinbergCalculator(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/project_config.ini',
+# test = KleinbergCalculator(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals/project_folder/project_config.ini',
 #                            classifier_names=['Attack'],
 #                            sigma=1.1,
 #                            gamma=0.3,
 #                            hierarchy=5,
-#                            hierarchical_search=True)
+#                            hierarchical_search=False)
 #
 # test.perform_kleinberg()
 # #data = run_kleinberg(r'Z:\DeepLabCut\DLC_extract\Troubleshooting\DLC_two_mice\project_folder\project_config.ini', ['int'], sigma=2, gamma=0.3, hierarchy=1)
\ No newline at end of file
