@@ -1,51 +1,15 @@
 from tkinter import *
 import glob, os
 from simba.misc_tools import get_fn_ext, get_video_meta_data
-import tkinter.ttk as ttk
-import platform
+from simba.tkinter_functions import hxtScrollbar
+import re
 import datetime
 import cv2
 from simba.read_config_unit_tests import check_file_exist_and_readable
 import json
 from simba.batch_process_videos.batch_process_create_ffmpeg_commands import FFMPEGCommandCreator
-
-def onMousewheel(event, canvas):
-    try:
-        scrollSpeed = event.delta
-        if platform.system() == 'Darwin':
-            scrollSpeed = event.delta
-        elif platform.system() == 'Windows':
-            scrollSpeed = int(event.delta / 120)
-        canvas.yview_scroll(-1 * (scrollSpeed), "units")
-    except:
-        pass
-
-def bindToMousewheel(event, canvas):
-    canvas.bind_all("<MouseWheel>", lambda event: onMousewheel(event, canvas))
-
-def unbindToMousewheel(event, canvas):
-    canvas.unbind_all("<MouseWheel>")
-
-def onFrameConfigure(canvas):
-    canvas.configure(scrollregion=canvas.bbox("all"))
-
-def hxtScrollbar(master):
-    bg = master.cget("background")
-    acanvas = Canvas(master, borderwidth=0, background=bg)
-    frame = Frame(acanvas, background=bg)
-    vsb = Scrollbar(master, orient="vertical", command=acanvas.yview)
-    vsb2 = Scrollbar(master, orient='horizontal', command=acanvas.xview)
-    acanvas.configure(yscrollcommand=vsb.set)
-    acanvas.configure(xscrollcommand=vsb2.set)
-    vsb.pack(side="right", fill="y")
-    vsb2.pack(side="bottom", fill="x")
-    acanvas.pack(side="left", fill="both", expand=True)
-
-    acanvas.create_window((10, 10), window=frame, anchor="nw")
-    acanvas.bind("<Configure>", lambda event, canvas=acanvas: onFrameConfigure(acanvas))
-    acanvas.bind('<Enter>', lambda event: bindToMousewheel(event, acanvas))
-    acanvas.bind('<Leave>', lambda event: unbindToMousewheel(event,acanvas))
-    return frame
+from simba.utils.errors import NoFilesFoundError
+from simba.enums import Options
 
 class BatchProcessFrame(object):
     """
@@ -74,9 +38,6 @@ class BatchProcessFrame(object):
 
     """
 
-
-
-
     def __init__(self,
                  input_dir: str,
                  output_dir: str):
@@ -87,17 +48,14 @@ class BatchProcessFrame(object):
             os.makedirs(self.output_dir)
         self.videos_in_dir_dict, self.crop_dict = {}, {}
         self.get_input_files()
-        if len(self.input_dir) == 0:
-            print('SIMBA WARNING: The input directory {} contains ZERO video files in either .avi, .mp4, .mov, .flv, or m4v format'.format(self.input_dir))
-        else:
-            self.max_char_vid_name = len(max(list(self.videos_in_dir_dict.keys()), key=len))
-
-
+        if len(list(self.videos_in_dir_dict.keys())) == 0:
+            raise NoFilesFoundError(msg=f'The input directory {self.input_dir} contains ZERO video files in either .avi, .mp4, .mov, .flv, or m4v format')
+        self.max_char_vid_name = len(max(list(self.videos_in_dir_dict.keys()), key=len))
 
     def get_input_files(self):
         for file_path in glob.glob(self.input_dir + '/*'):
             lower_str_name = file_path.lower()
-            if lower_str_name.endswith(('.avi', '.mp4', '.mov', '.flv', '.m4v')):
+            if lower_str_name.endswith(Options.ALL_VIDEO_FORMAT_OPTIONS.value):
                 _, video_name, ext = get_fn_ext(file_path)
                 self.videos_in_dir_dict[video_name] = get_video_meta_data(file_path)
                 self.videos_in_dir_dict[video_name]['extension'] = ext
