@@ -18,6 +18,7 @@ from simba.bounding_box_tools.find_bounderies import AnimalBoundaryFinder
 from simba.bounding_box_tools.visualize_boundaries import BoundaryVisualizer
 from simba.bounding_box_tools.boundary_statistics import BoundaryStatisticsCalculator
 from simba.bounding_box_tools.agg_boundary_stats import AggBoundaryStatisticsCalculator
+from simba.utils.errors import NoFilesFoundError, NoChoosenMeasurementError
 
 class BoundaryMenus(object):
     """
@@ -129,8 +130,7 @@ class BoundaryMenus(object):
     def __launch_visualize_boundaries(self):
         self.anchored_roi_path = os.path.join(self.project_path, 'logs', 'anchored_rois.pickle')
         if not os.path.isfile(self.anchored_roi_path):
-            print('SIMBA ERROR: No anchored ROI found in {}'.format(self.anchored_roi_path))
-            raise FileNotFoundError()
+            raise NoFilesFoundError(msg='SIMBA ERROR: No anchored ROI found in {}.'.format(self.anchored_roi_path))
         with open(self.anchored_roi_path, 'rb') as fp: self.roi_data = pickle.load(fp)
         videos_in_project = glob.glob(self.video_dir + '/*')
         videos_with_data = list(self.roi_data.keys())
@@ -143,8 +143,7 @@ class BoundaryMenus(object):
             video_names.append(name)
         sets_w_data_and_video = list(set(videos_with_data).intersection(video_names))
         if len(sets_w_data_and_video) == 0:
-            print('SIMBA ERROR: Zero video files found with calculated anchored ROIs in SimBA project')
-            raise ValueError()
+            raise NoFilesFoundError(msg='SIMBA ERROR: Zero video files found with calculated anchored ROIs in SimBA project')
         self.viz_boundaries_frm = Toplevel()
         self.viz_boundaries_frm.minsize(600, 150)
         self.viz_boundaries_frm.wm_title("VISUALIZE ANIMAL BOUNDARIES")
@@ -242,8 +241,7 @@ class BoundaryMenus(object):
     def __launch_boundary_statistics(self):
         self.anchored_roi_path = os.path.join(self.project_path, 'logs', 'anchored_rois.pickle')
         if not os.path.isfile(self.anchored_roi_path):
-            print('SIMBA ERROR: No anchored ROI data found at {}'.format(self.anchored_roi_path))
-            raise FileNotFoundError()
+            raise NoFilesFoundError(msg='SIMBA ERROR: No anchored ROI found in {}.'.format(self.anchored_roi_path))
         self.statistics_frm = Toplevel()
         self.statistics_frm.minsize(400, 150)
         self.statistics_frm.wm_title("ANIMAL ANCHORED ROI STATISTICS")
@@ -272,8 +270,7 @@ class BoundaryMenus(object):
         roi_intersections = self.roi_intersections_var.get()
         roi_keypoint_intersections = self.roi_keypoint_intersections_var.get()
         if (not roi_intersections) and (not roi_keypoint_intersections):
-            print('SIMBA ERROR: Please select at least one category of statistics')
-            raise ValueError()
+            raise NoChoosenMeasurementError()
         statistics_calculator = BoundaryStatisticsCalculator(config_path=self.config_path,
                                                              roi_intersections=roi_intersections,
                                                              roi_keypoint_intersections=roi_keypoint_intersections,
@@ -283,8 +280,7 @@ class BoundaryMenus(object):
     def __launch_agg_boundary_statistics(self):
         self.data_path = os.path.join(self.project_path, 'csv', 'anchored_roi_data')
         if not os.path.isdir(self.data_path):
-            print('SIMBA ERROR: No anchored roi statistics found in {}'.format(self.data_path))
-            raise ValueError
+            raise NoFilesFoundError(msg='SIMBA ERROR: No anchored ROI statistics found in {}.'.format(self.anchored_roi_path))
         self.main_agg_statistics_frm = Toplevel()
         self.main_agg_statistics_frm.minsize(400, 175)
         self.main_agg_statistics_frm.wm_title("ANIMAL ANCHORED ROI AGGREGATE STATISTICS")
@@ -321,8 +317,7 @@ class BoundaryMenus(object):
         check_int(name='MIN BOUT LENGTH', value=min_bout)
         if min_bout == '': min_bout = 0
         if len(measures) == 0:
-            print('SIMBA ERROR: Select at least one descriptive statistics checkbox')
-            raise ValueError()
+            raise NoChoosenMeasurementError()
 
         agg_stats_calculator = AggBoundaryStatisticsCalculator(config_path=self.config_path,
                                                                measures=measures,
