@@ -11,6 +11,7 @@ from joblib import Parallel, delayed
 from shapely.geometry import Point
 from copy import deepcopy
 from collections import defaultdict
+from simba.utils.errors import NoFilesFoundError
 import os
 import pickle
 
@@ -54,8 +55,7 @@ class BoundaryStatisticsCalculator(object):
         self.input_dir = os.path.join(self.project_path, Paths.OUTLIER_CORRECTED.value)
         self.save_folder = os.path.join(self.project_path, 'csv', 'anchored_roi_data')
         if not os.path.isfile(self.anchored_roi_path):
-            print('No anchored ROI data detected. Extract anchored ROIs before computing statistics')
-            raise FileNotFoundError()
+            raise NoFilesFoundError(msg=f'No anchored ROI data detected. Extract anchored ROIs before computing statistics. File expected at path {self.anchored_roi_path}')
         with open(self.anchored_roi_path, 'rb') as fp: self.polygons = pickle.load(fp)
         self.no_animals = read_config_entry(self.config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.ANIMAL_CNT.value, Dtypes.INT.value)
         self.multi_animal_status, self.multi_animal_id_lst = check_multi_animal_status(self.config, self.no_animals)
