@@ -2,7 +2,7 @@ from simba.read_config_unit_tests import (read_config_file,
                                           read_config_entry,
                                           check_if_filepath_list_is_empty)
 from simba.rw_dfs import read_df
-from simba.features_scripts.unit_tests import (read_video_info_csv,
+from simba.feature_extractors.unit_tests import (read_video_info_csv,
                                                read_video_info)
 from simba.drop_bp_cords import (create_body_part_dictionary,
                                  get_fn_ext,
