@@ -22,6 +22,7 @@ import multiprocessing
 from multiprocessing import pool
 import platform
 import os, glob
+from simba.utils.errors import NoFilesFoundError
 
 def _image_creator(frm_range: list,
                    polygon_data: dict,
@@ -145,8 +146,7 @@ class BoundaryVisualizer(object):
         if self.include_key_points:
             self.data_df_path = os.path.join(self.input_dir, self.video_name + '.' + self.file_type)
             if not os.path.isfile(self.data_df_path):
-                print('SIMBA ERROR: No keypoint data found in {} for video {}. Untick key-point checkbox or import pose-estimation data.')
-                raise FileNotFoundError()
+                raise NoFilesFoundError(msg=f'SIMBA ERROR: No keypoint data found in {self.data_df_path}. Untick key-point checkbox or import pose-estimation data.')
             self.data_df = read_df(file_path=self.data_df_path, file_type=self.file_type).astype(int).reset_index(drop=True)
         else:
             self.data_df = None
