@@ -17,12 +17,13 @@ from simba.drop_bp_cords import getBpNames
 import cv2
 import numpy as np
 import multiprocessing
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
+from simba.feature_extractors.unit_tests import read_video_info_csv, read_video_info
 import functools
 import time
 import platform
 from shapely.geometry import Polygon
 from joblib import Parallel, delayed
+from simba.utils.errors import NoFilesFoundError, CountError, NoROIDataError
 
 
 
@@ -98,9 +99,7 @@ class CueLightAnalyzer(object):
 
 
         if len(cue_light_names) == 0:
-            print('SIMBA ERROR: Please select one or more cue lights')
-            raise ValueError('SIMBA ERROR: Please select one or more cue lights')
-
+            raise CountError(msg='SIMBA ERROR: Please select one or more cue lights')
         if platform.system() == "Darwin":
             multiprocessing.set_start_method('spawn', force=True)
 
@@ -119,8 +118,7 @@ class CueLightAnalyzer(object):
         self.multi_animal_status, self.multi_animal_id_lst = check_multi_animal_status(self.config, self.no_animals)
         self.animal_bp_dict = create_body_part_dictionary(self.multi_animal_status, self.multi_animal_id_lst, self.no_animals, self.x_cols, self.y_cols, self.p_cols, [])
         if len(self.files_found) == 0:
-            print('SIMBA ERROR: Zero tracking files detected in the "project_folder/csv/outlier_corrected_movement_location" directory')
-            raise ValueError('SIMBA ERROR: Zero tracking files detected in the "project_folder/csv/outlier_corrected_movement_location" directory')
+            raise NoFilesFoundError(msg='SIMBA ERROR: Zero tracking files detected in the "project_folder/csv/outlier_corrected_movement_location" directory')
         _, self.cpu_cnt_to_use = find_core_cnt()
         self.maxtasksperchild = 10
         self.chunksize = 1
@@ -129,7 +127,7 @@ class CueLightAnalyzer(object):
 
     def read_roi_dfs(self):
         if not os.path.isfile(os.path.join(self.logs_path, 'measures', 'ROI_definitions.h5')):
-            raise FileNotFoundError(print('No ROI definitions were found in your SimBA project. Please draw some ROIs before analyzing your ROI data'))
+            raise NoROIDataError(msg='No ROI definitions were found in your SimBA project. Please draw some ROIs before analyzing your ROI data')
         else:
             self.roi_h5_path = os.path.join(self.logs_path, 'measures', 'ROI_definitions.h5')
             self.rectangles_df = pd.read_hdf(self.roi_h5_path, key='rectangles')
