@@ -11,6 +11,7 @@ from simba.cue_light_tools.cue_light_visualizer import CueLightVisualizer
 from simba.train_model_functions import get_all_clf_names
 from simba.cue_light_tools.cue_light_clf_statistics import CueLightClfAnalyzer
 from simba.cue_light_tools.cue_light_movement_statistics import CueLightMovementAnalyzer
+from simba.utils.errors import NoFilesFoundError, CountError, NoROIDataError, NoChoosenClassifierError
 import webbrowser
 
 def onMousewheel(event, canvas):
@@ -86,8 +87,7 @@ class CueLightAnalyzerMenu(object):
         self.file_type = read_config_entry(self.config, 'General settings', 'workflow_file_type', 'str', 'csv')
         self.__read_roi_dfs()
         if len(self.shape_names) == 0:
-            print('SIMBA ERROR: Cue light analysis require ROI definitions. Please define ROIs before doing cue light analysis')
-            raise ValueError('SIMBA ERROR: Cue light analysis require ROI definitions. Please define ROIs before doing cue light analysis')
+            raise CountError(msg='SIMBA ERROR: Cue light analysis require ROI definitions. Please define ROIs before doing cue light analysis')
         self.cue_light_main_frame = Toplevel()
         self.cue_light_main_frame.minsize(750, 300)
         self.cue_light_main_frame.wm_title("SIMBA CUE LIGHT ANALYZER")
@@ -148,8 +148,7 @@ class CueLightAnalyzerMenu(object):
 
     def __read_roi_dfs(self):
         if not os.path.isfile(os.path.join(self.logs_path, 'measures', 'ROI_definitions.h5')):
-            print('No ROI definitions were found in your SimBA project. Please draw some ROIs before analyzing your ROI data')
-            raise FileNotFoundError('No ROI definitions were found in your SimBA project. Please draw some ROIs before analyzing your ROI data')
+            raise NoROIDataError(msg='No ROI definitions were found in your SimBA project. Please draw some ROIs before analyzing your ROI data')
         else:
             self.roi_h5_path = os.path.join(self.logs_path, 'measures', 'ROI_definitions.h5')
             self.rectangles_df = pd.read_hdf(self.roi_h5_path, key='rectangles')
@@ -165,8 +164,7 @@ class CueLightAnalyzerMenu(object):
     def __visualize_cue_light_data(self):
         self.cue_light_data_files = glob.glob(self.cue_light_data_folder + '/*' + self.file_type)
         if len(self.cue_light_data_files) == 0:
-            print('SIMBA ERROR: Zero data files found. Please analyze cue light data prior to visualizing cue light data')
-            raise ValueError('SIMBA ERROR: Zero data files found. Please analyze cue light data prior to visualizing cue light data')
+            raise NoFilesFoundError(msg='SIMBA ERROR: Zero data files found. Please analyze cue light data prior to visualizing cue light data')
         else:
             self.__get_cue_light_names()
             for data_path in self.cue_light_data_files:
@@ -237,8 +235,7 @@ class CueLightAnalyzerMenu(object):
     def start_movement_analysis(self):
         self.__get_cue_light_names()
         if len(self.light_lst) == 0:
-            print('SIMBA ERROR: Zero user-specified cue lights. Please specify cue lights before analyzing movements')
-            raise ValueError('SIMBA ERROR: Zero user-specified cue lights. Please specify cue lights before analyzing movements')
+            raise CountError(msg='Zero user-specified cue lights. Please specify cue lights before analyzing movements')
         if not self.config.has_section('Cue light analysis'):
             self.config.add_section('Cue light analysis')
         for animal_cnt, animal_data in self.animal_dict.items():
@@ -305,13 +302,11 @@ class CueLightAnalyzerMenu(object):
         clf_lst = []
         self.__get_cue_light_names()
         if len(self.light_lst) == 0:
-            print('SIMBA ERROR: Zero data files found. Please analyze cue light data prior to visualizing cue light data')
-            raise ValueError('SIMBA ERROR: Zero data files found. Please analyze cue light data prior to visualizing cue light data')
+            raise NoFilesFoundError(msg='SIMBA ERROR: Zero data files found. Please analyze cue light data prior to visualizing cue light data')
         for clf_name, clf_setting in self.entry_dict.items():
             if clf_setting['var'].get(): clf_lst.append(clf_name)
         if len(clf_lst) == 0:
-            print('SIMBA ERROR: Please tick at least one 1 classifier option')
-            raise ValueError('SIMBA ERROR: Please tick at least one 1 classifier option')
+            raise NoChoosenClassifierError()
         else:
             clf_cue_light_analyzer = CueLightClfAnalyzer(config_path=self.config_path,
                                                          pre_window=self.pre_window_var_clf.get(),
