@@ -5,8 +5,7 @@ import pandas as pd
 import os
 from pathlib import Path
 from configparser import (ConfigParser,
-                          NoOptionError,
-                          NoSectionError)
+                          NoOptionError)
 import glob
 import re
 from pylab import cm
@@ -17,6 +16,7 @@ from simba.read_config_unit_tests import (read_config_entry,
                                           read_config_file,
                                           check_file_exist_and_readable)
 from simba.enums import ReadConfig, Paths
+from simba.utils.errors import InvalidFilepathError
 
 
 def create_body_part_dictionary(multiAnimalStatus: bool,
@@ -41,7 +41,7 @@ def create_body_part_dictionary(multiAnimalStatus: bool,
     Xcols: list
         list of column names for body-part coordinates on x-axis
     Ycols: list
-        list of column names for body-part coordinates on y-axis
+         column names for body-part coordinates on y-axis
     Pcols: list
         list of column names for body-part pose-estimation probability values
     colorListofList: list or None
@@ -279,7 +279,7 @@ def define_movement_cols(multi_animal_id_list: list):
 
 def bodypartConfSchematic():
     """Helper to return (i) named body-part schematics of all pose-estimation schemas in SimBA installation, and
-    (ii) the paths to the images representing those  body-part schematics in SimBA installation
+    (ii) the paths to the images representing those body-part schematics in SimBA installation
     """
 
     optionsBaseListImagesPath = os.path.join(os.path.dirname(__file__), Paths.SCHEMATICS.value)
@@ -491,8 +491,7 @@ def get_fn_ext(filepath: str):
     try:
         file_name = os.path.basename(filepath.rsplit(file_extension, 1)[0])
     except ValueError:
-        print('SIMBA ERROR: {} is not a valid filepath'.format(filepath))
-        raise ValueError('SIMBA ERROR: {} is not a valid filepath'.format(filepath))
+        raise InvalidFilepathError(msg='{} is not a valid filepath'.format(filepath))
     dir_name = os.path.dirname(filepath)
     return dir_name, file_name, file_extension
 
