@@ -17,6 +17,8 @@ from subprocess import Popen, PIPE
 import os
 from simba.train_model_functions import get_all_clf_names
 from simba.enums import ReadConfig, Paths, Dtypes
+from tabulate import tabulate
+from simba.utils.errors import FrameRangeError, AdvancedLabellingError
 
 class AdvancedLabellingInterface(object):
     """
@@ -100,6 +102,11 @@ class AdvancedLabellingInterface(object):
         self.forward_btn = Button(self.buttons_frm, text=">", command=lambda: self.advance_frame(new_frm_number=int(self.current_frm_n.get() + 1)))
         self.backward_btn = Button(self.buttons_frm, text="<", command=lambda: self.advance_frame(new_frm_number=int(self.current_frm_n.get() - 1)))
         self.forward_max_btn = Button(self.buttons_frm, text=">>", command=lambda: self.advance_frame(len(self.frame_lst) - 1))
+        self.next_absent_forward_btn = Button(self.buttons_frm, text="NEXT ABSENT", fg='red', command=lambda: self.find_last_next_annotation(forwards=True, present=False))
+        self.next_present_forward_btn = Button(self.buttons_frm, text="NEXT PRESENT", fg='blue', command=lambda: self.find_last_next_annotation(forwards=True, present=True))
+        self.last_absent_forward_btn = Button(self.buttons_frm, text="PREVIOUS ABSENT", fg='red', command=lambda: self.find_last_next_annotation(forwards=False, present=False))
+        self.last_present_forward_btn = Button(self.buttons_frm, text="PREVIOUS PRESENT", fg='blue', command=lambda: self.find_last_next_annotation(forwards=False, present=True))
+
         self.backward_max_btn = Button(self.buttons_frm, text="<<", command=lambda: self.advance_frame(0))
         self.select_frm_btn = Button(self.buttons_frm, text="Jump to selected frame", command=lambda: self.advance_frame(new_frm_number=int(self.change_frm_box.get())))
         self.jump_frame = Frame(self.main_window)
@@ -113,18 +120,22 @@ class AdvancedLabellingInterface(object):
         self.buttons_frm.grid(row=1, column=0)
         self.change_frm_box.grid(row=0, column=1)
         self.forward_btn.grid(row=1, column=3, sticky=E, padx=self.padding)
-        self.backward_btn.grid(row=1, column=1, sticky=W, padx=self.padding)
-        self.change_frm_box.grid(row=1, column=1)
-        self.forward_max_btn.grid(row=1, column=4, sticky=W, padx=self.padding)
-        self.backward_max_btn.grid(row=1, column=0, sticky=W, padx=self.padding)
-        self.select_frm_btn.grid(row=2, column=1, sticky=N)
+        self.last_present_forward_btn.grid(row=1, column=0, sticky=W, padx=self.padding)
+        self.last_absent_forward_btn.grid(row=1, column=1, sticky=W, padx=self.padding)
+        self.backward_max_btn.grid(row=1, column=2, sticky=W, padx=self.padding)
+        self.backward_btn.grid(row=1, column=3, sticky=W, padx=self.padding)
+        self.change_frm_box.grid(row=1, column=4)
+        self.forward_max_btn.grid(row=1, column=5, sticky=W, padx=self.padding)
+        self.next_absent_forward_btn.grid(row=1, column=6, sticky=W, padx=self.padding)
+        self.next_present_forward_btn.grid(row=1, column=7, sticky=W, padx=self.padding)
+
+        self.select_frm_btn.grid(row=2, column=4, sticky=N)
         self.jump_frame.grid(row=2, column=0)
         self.jump.grid(row=0, column=0, sticky=W)
         self.jump_size.grid(row=0, column=1, sticky=W)
         self.jump_back.grid(row=0, column=2, sticky=E)
         self.jump_forward.grid(row=0, column=3, sticky=W)
 
-        ## Behavior Checkbox
         self.check_frame = Frame(self.main_window, bd=2, width=300, height=500)
         self.check_frame.grid(row=0, column=1)
         self.check_behavior_lbl = Label(self.check_frame, text="Check Behavior:")
@@ -205,6 +216,30 @@ class AdvancedLabellingInterface(object):
         self.main_window.bind('<Control-o>', lambda x: self.advance_frame(0))
 
 
+    def find_last_next_annotation(self, forwards: bool, present: bool):
+        if forwards:
+            sliced = self.data_df_targets.loc[self.current_frm_n.get()+1:,].sum(axis=1)
+            if present:
+                frms = list(sliced.index[sliced > 1])
+            else:
+                frms = list(sliced.index[sliced == 0])
+            if len(frms) > 0:
+                frm = frms[0]
+            else:
+                raise FrameRangeError('No forwards frames with annotation detected')
+        else:
+            sliced = self.data_df_targets.loc[0:self.current_frm_n.get()-1 , ].sum(axis=1)
+            if present:
+                frms = list(sliced.index[sliced > 1])
+            else:
+                frms = list(sliced.index[sliced == 0])
+            if len(frms) > 0:
+                frm = frms[-1]
+            else:
+                raise FrameRangeError('No backwards frames with annotation detected')
+
+        self.advance_frame(new_frm_number=frm, keep_prior_img_cb_status=False)
+
     def __print_annotation_statistics(self):
         table_view = [["Video name", self.video_name], ['Video frames', self.video_meta_data['frame_count']]]
         for target in self.target_lst:
@@ -310,20 +345,15 @@ class AdvancedLabellingInterface(object):
         check_int('START FRAME', int(start_frm), max_value=self.max_frm_no, min_value=0)
         check_int('END FRAME', int(end_frm), max_value=self.max_frm_no, min_value=0)
         if not self.range_on.get():
-            print('SAVE RANGE ERROR: TO SAVE RANGE OF FRAMES, TICK THE `Frame range` checkbox before clicking `Save Range`')
-            raise ValueError('SAVE RANGE ERROR: TO SAVE RANGE OF FRAMES, TICK THE `Frame range` checkbox before clicking `Save Range`')
+            raise FrameRangeError(msg='TO SAVE RANGE OF FRAMES, TICK THE `Frame range` checkbox before clicking `Save Range`')
         elif start_frm < 0:
-            print("FRAME RANGE ERROR: START FRAME {} IS LESS THAN ZERO AND CANNOT BE SHOWN".format(str(start_frm)))
-            raise ValueError("FRAME RANGE ERROR: START FRAME {} IS LESS THAN ZERO AND CANNOT BE SHOWN".format(str(start_frm)))
+            raise FrameRangeError(msg="FRAME RANGE ERROR: START FRAME {} IS LESS THAN ZERO AND CANNOT BE SHOWN".format(str(start_frm)))
         elif end_frm > self.max_frm_no:
-            print("FRAME RANGE ERROR: END FRAME {} IS MORE THAN THE MAX VIDEO FRAME ({}) AND CANNOT BE SHOWN".format(str(end_frm), str(self.max_frm_no)))
-            raise ValueError("FRAME RANGE ERROR: END FRAME {} IS MORE THAN THE MAX VIDEO FRAME ({}) AND CANNOT BE SHOWN".format(str(end_frm), str(self.max_frm_no)))
+            raise FrameRangeError(msg="FRAME RANGE ERROR: END FRAME {} IS MORE THAN THE MAX VIDEO FRAME ({}) AND CANNOT BE SHOWN".format(str(end_frm), str(self.max_frm_no)))
         elif start_frm == end_frm:
-            print("FRAME RANGE ERROR: START FRAME AND END FRAME IS SET TO THE SAME VALUE ({}) AND DOES NOT REPRESENT A RANGE".format(str(end_frm)))
-            raise ValueError("FRAME RANGE ERROR: START FRAME AND END FRAME IS SET TO THE SAME VALUE ({}) AND DOES NOT REPRESENT A RANGE".format(str(end_frm)))
+            raise FrameRangeError(msg="FRAME RANGE ERROR: START FRAME AND END FRAME IS SET TO THE SAME VALUE ({}) AND DOES NOT REPRESENT A RANGE".format(str(end_frm)))
         elif start_frm > end_frm:
-            print("FRAME RANGE ERROR: START FRAME ({}) IS LARGER THAB THE END FRAME ({}). PLEASE SPECIFY A RANGE OF FRAMES WHERE THE START FRAME PRECEDE THE END FRAME".format(str(start_frm), str(end_frm)))
-            raise ValueError("FRAME RANGE ERROR: START FRAME ({}) IS LARGER THAB THE END FRAME ({}). PLEASE SPECIFY A RANGE OF FRAMES WHERE THE START FRAME PRECEDE THE END FRAME".format(str(start_frm), str(end_frm)))
+            raise FrameRangeError(msg="FRAME RANGE ERROR: START FRAME ({}) IS LARGER THAB THE END FRAME ({}). PLEASE SPECIFY A RANGE OF FRAMES WHERE THE START FRAME PRECEDE THE END FRAME".format(str(start_frm), str(end_frm)))
         else:
             for frm_no in range(int(start_frm), int(end_frm) + 1):
                 for target in self.target_lst:
@@ -363,12 +393,7 @@ class AdvancedLabellingInterface(object):
             else:
                 labelled_target_lst.append(target)
         if (len(none_target_lst) > 0) & (len(labelled_target_lst) > 0):
-            self.msg = 'SIMBA ERROR: In advanced labelling of multiple behaviors, any annotated frame cannot have some ' \
-                       'behaviors annotated as present/absent, while other behaviors are un-labelled. All behaviors need ' \
-                       'labels for a frame with one or more labels. In frame {}, behaviors {} are labelled, while behaviors ' \
-                       '{} are un-labelled.'.format(str(self.current_frm_n.get()), labelled_target_lst, none_target_lst)
-            print(self.msg)
-            raise ValueError(self.msg)
+            raise AdvancedLabellingError(frame=str(self.current_frm_n.get()), lbl_lst=labelled_target_lst, unlabel_lst=none_target_lst)
 
     def create_print_statements(self, frame_range: bool=None, start_frame: int=None, end_frame: int=None):
         print('USER FRAME SELECTION(S):')
@@ -405,5 +430,5 @@ def select_labelling_video_advanced(config_path: str=None,
                           file_path=video_file_path,
                           continuing=continuing)
 
-# test = select_labelling_video_advanced(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini',
-#                           continuing=True)
+# test = select_labelling_video_advanced(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/project_config.ini',
+#                           continuing=False)
