@@ -1,4 +1,4 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
 import time
 
@@ -21,6 +21,7 @@ from subprocess import Popen, PIPE
 import os
 from simba.train_model_functions import get_all_clf_names
 from tabulate import tabulate
+from simba.utils.errors import FrameRangeError
 
 class LabellingInterface(object):
     """
@@ -276,8 +277,7 @@ class LabellingInterface(object):
 
     def __save_behavior_in_range(self, start_frm=None, end_frm=None):
         if not self.range_on.get():
-            print('SAVE RANGE ERROR: TO SAVE RANGE OF FRAMES, TICK THE `Frame range` checkbox before clicking `Save Range`')
-            raise ValueError('SAVE RANGE ERROR: TO SAVE RANGE OF FRAMES, TICK THE `Frame range` checkbox before clicking `Save Range`')
+            raise FrameRangeError('SAVE RANGE ERROR: TO SAVE RANGE OF FRAMES, TICK THE `Frame range` checkbox before clicking `Save Range`')
         else:
             check_int('START FRAME', int(start_frm), max_value=self.max_frm_no, min_value=0)
             check_int('END FRAME', int(end_frm), max_value=self.max_frm_no, min_value=0)
