@@ -1,3 +1,6 @@
+__author__ = "Simon Nilsson"
+
+
 from simba.read_config_unit_tests import (read_config_entry,
                                           read_config_file,
                                           check_int,
@@ -13,10 +16,13 @@ from simba.enums import ReadConfig, Options, Formats
 from simba.train_model_functions import get_all_clf_names
 from simba.misc_tools import (find_files_of_filetypes_in_directory,
                               get_fn_ext)
+from simba.utils.errors import InvalidHyperparametersFileError
+from simba.mixins.pop_up_mixin import PopUpMixin
 import webbrowser
 from tkinter import *
+from tkinter import ttk
 
-class MachineModelSettingsPopUp(object):
+class MachineModelSettingsPopUp(PopUpMixin):
     def __init__(self,
                  config_path: str):
 
@@ -86,6 +92,7 @@ class MachineModelSettingsPopUp(object):
         self.create_clf_importance_bars_var = BooleanVar()
         self.feature_permutation_importance_var = BooleanVar()
         self.create_pr_curve_var = BooleanVar()
+        self.partial_dependency_var =BooleanVar()
         self.calc_shap_scores_var = BooleanVar()
         self.learning_curve_var = BooleanVar()
 
@@ -94,16 +101,20 @@ class MachineModelSettingsPopUp(object):
         self.decision_tree_dtreeviz_cb = Checkbutton(self.evaluations_frm, text='Create Fancy Example Decision Tree (requires "dtreeviz")', variable=self.create_example_decision_tree_dtreeviz_var)
         self.clf_report_cb = Checkbutton(self.evaluations_frm, text='Create Classification Report', variable=self.create_clf_report_var)
         self.n_features_bars_entry_box = Entry_Box(self.evaluations_frm, '# Features: ', '25', status=DISABLED, validation='numeric')
-        self.bar_graph_cb = Checkbutton(self.evaluations_frm, text='Create Features Importance Bar Graph', variable=self.create_clf_importance_bars_var, command=lambda: self.checkbox_switch_entry_box_state(self.create_clf_importance_bars_var, [self.n_features_bars_entry_box]))
+        self.bar_graph_cb = Checkbutton(self.evaluations_frm, text='Create Features Importance Bar Graph', variable=self.create_clf_importance_bars_var, command=lambda: self.enable_entrybox_from_checkbox(check_box_var=self.create_clf_importance_bars_var, entry_boxes=[self.n_features_bars_entry_box]))
         self.feature_permutation_cb = Checkbutton(self.evaluations_frm, text='Compute Feature Permutation Importances (Note: CPU intensive)', variable=self.feature_permutation_importance_var)
         self.learning_curve_k_splits_entry_box = Entry_Box(self.evaluations_frm, 'Learning Curve Shuffle K Splits', '25',status=DISABLED, validation='numeric')
         self.learning_curve_data_splits_entry_box = Entry_Box(self.evaluations_frm, 'Learning Curve Shuffle Data Splits', '25',status=DISABLED, validation='numeric')
-        self.learning_curve_cb = Checkbutton(self.evaluations_frm, text='Create Learning Curves (Note: CPU intensive)', variable=self.learning_curve_var, command=lambda: self.checkbox_switch_entry_box_state(self.learning_curve_var, [self.learning_curve_k_splits_entry_box, self.learning_curve_data_splits_entry_box]))
+        self.learning_curve_cb = Checkbutton(self.evaluations_frm, text='Create Learning Curves (Note: CPU intensive)', variable=self.learning_curve_var, command=lambda: self.enable_entrybox_from_checkbox(check_box_var=self.learning_curve_var, entry_boxes=[self.learning_curve_k_splits_entry_box, self.learning_curve_data_splits_entry_box]))
         self.create_pr_curve_cb = Checkbutton(self.evaluations_frm, text='Create Precision Recall Curves', variable=self.create_pr_curve_var)
         self.shap_present = Entry_Box(self.evaluations_frm, '# target present', '25', status=DISABLED, validation='numeric')
         self.shap_absent = Entry_Box(self.evaluations_frm, '# target absent', '25', status=DISABLED,  validation='numeric')
-        self.calculate_shap_scores_cb = Checkbutton(self.evaluations_frm, text='Calculate SHAP scores', variable=self.calc_shap_scores_var, command=lambda: self.checkbox_switch_entry_box_state(checkbox_var=self.calc_shap_scores_var, entry_boxes=[self.shap_present,self.shap_absent]))
-
+        self.shap_save_it_dropdown = DropDownMenu(self.evaluations_frm, 'SHAP save cadence: ', [1, 10, 100, 1000, 'ALL FRAMES'],  '25')
+        self.shap_save_it_dropdown.setChoices('ALL FRAMES')
+        self.shap_save_it_dropdown.disable()
+        self.partial_dependency_cb = Checkbutton(self.evaluations_frm, text='Calculate partial dependencies', variable=self.partial_dependency_var)
+        self.calculate_shap_scores_cb = Checkbutton(self.evaluations_frm, text='Calculate SHAP scores', variable=self.calc_shap_scores_var, command=lambda: [self.enable_entrybox_from_checkbox(check_box_var=self.calc_shap_scores_var, entry_boxes=[self.shap_present,self.shap_absent]),
+                                                                                                                                                             self.enable_dropdown_from_checkbox(check_box_var=self.calc_shap_scores_var, dropdown_menus=[self.shap_save_it_dropdown])])
         self.save_frame = LabelFrame(main, text='SAVE', font=Formats.LABELFRAME_HEADER_FORMAT.value)
         save_global_btn = Button(self.save_frame, text='SAVE SETTINGS (GLOBAL ENVIRONMENT)', font=('Helvetica', 12, 'bold'), fg='blue', command=lambda: self.save_global())
         save_meta_btn = Button(self.save_frame, text='SAVE SETTINGS (SPECIFIC MODEL)', font=('Helvetica', 12, 'bold'), fg='green', command=lambda: self.save_config())
@@ -145,9 +156,11 @@ class MachineModelSettingsPopUp(object):
         self.learning_curve_k_splits_entry_box.grid(row=8, column=0, sticky=NW)
         self.learning_curve_data_splits_entry_box.grid(row=9, column=0, sticky=NW)
         self.create_pr_curve_cb.grid(row=10, column=0, sticky=NW)
-        self.calculate_shap_scores_cb.grid(row=11, column=0, sticky=NW)
-        self.shap_present.grid(row=12, column=0, sticky=NW)
-        self.shap_absent.grid(row=13, column=0, sticky=NW)
+        self.partial_dependency_cb.grid(row=11, column=0, sticky=NW)
+        self.calculate_shap_scores_cb.grid(row=12, column=0, sticky=NW)
+        self.shap_present.grid(row=13, column=0, sticky=NW)
+        self.shap_absent.grid(row=14, column=0, sticky=NW)
+        self.shap_save_it_dropdown.grid(row=15, column=0, sticky=NW)
 
         self.save_frame.grid(row=5, column=0, sticky=NW)
         save_global_btn.grid(row=0, column=0, sticky=NW)
@@ -156,7 +169,6 @@ class MachineModelSettingsPopUp(object):
 
         main.mainloop()
 
-
     def dropdown_switch_entry_box_state(self,
                                         box,
                                         dropdown):
@@ -166,18 +178,6 @@ class MachineModelSettingsPopUp(object):
         else:
             box.set_state(DISABLED)
 
-
-    def checkbox_switch_entry_box_state(self,
-                                        checkbox_var,
-                                        entry_boxes):
-
-        if checkbox_var.get():
-            for entry_box in entry_boxes:
-                entry_box.set_state(NORMAL)
-        else:
-            for entry_box in entry_boxes:
-                entry_box.set_state(DISABLED)
-
     def create_class_weight_table(self):
         if hasattr(self, 'class_weight_frm'):
             self.weight_present.destroy()
@@ -247,11 +247,14 @@ class MachineModelSettingsPopUp(object):
         self.pr_curve = self.create_pr_curve_var.get()
         self.shap_scores_absent = 0
         self.shap_scores_present = 0
+        self.shap_save_it = 'ALL FRAMES'
         self.shap_scores = self.calc_shap_scores_var.get()
         if self.shap_scores:
             self.shap_scores_absent = self.shap_absent.entry_get
             self.shap_scores_present = self.shap_present.entry_get
+            self.shap_save_it = self.shap_save_it_dropdown.getChoices()
         self.learning_curve = self.learning_curve_var.get()
+        self.partial_dependency = self.partial_dependency_var.get()
         self.learning_curve_k_split = 0
         self.learning_curve_data_split = 0
         if self.learning_curve:
@@ -295,12 +298,13 @@ class MachineModelSettingsPopUp(object):
         self.config.set('create ensemble settings', 'generate_shap_scores', str(self.shap_scores))
         self.config.set('create ensemble settings', 'shap_target_present_no', str(self.shap_scores_present))
         self.config.set('create ensemble settings', 'shap_target_absent_no', str(self.shap_scores_absent))
+        self.config.set('create ensemble settings', 'shap_save_iteration', str(self.shap_save_it))
+        self.config.set('create ensemble settings', 'partial_dependency', str(self.partial_dependency))
         self.config.set('create ensemble settings', 'class_weights', str(self.class_weight_method))
         self.config.set('create ensemble settings', 'custom_weights', str(self.class_custom_weights))
 
         with open(self.config_path, 'w') as f:
             self.config.write(f)
-
         print('SIMBA COMPLETE: Global model settings saved in the project_folder/project_config.ini')
 
     def save_config(self):
@@ -331,6 +335,8 @@ class MachineModelSettingsPopUp(object):
                 'generate_shap_scores':self.shap_scores,
                 'shap_target_present_no':self.shap_scores_present,
                 'shap_target_absent_no':self.shap_scores_absent,
+                'shap_save_iteration': self.shap_save_it,
+                'partial_dependency': self.partial_dependency,
                 'class_weights': self.class_weight_method,
                 'class_custom_weights': str(self.class_custom_weights)}
 
@@ -340,7 +346,7 @@ class MachineModelSettingsPopUp(object):
         file_name = '{}_meta_{}.csv'.format(self.behavior_name, str(self.meta_file_cnt))
         save_path = os.path.join(self.configs_path, file_name)
         meta_df.to_csv(save_path, index=FALSE)
-        print('SIMBA COMPLETE: Hyper-parameter config ({}) saved in project_folder/configs folder'.format(str(len(self.total_meta_files)+1)))
+        print(f'SIMBA COMPLETE: Hyper-parameter config ({str(len(self.total_meta_files)+1)} saved in project_folder/configs folder.')
 
     def clear_cache(self):
         self.behavior_name = self.behavior_name_dropdown.getChoices()
@@ -368,9 +374,7 @@ class MachineModelSettingsPopUp(object):
         try:
             meta_df = pd.read_csv(config_file_path, index_col=False)
         except pd.errors.ParserError:
-            error_msg = 'SIMBA ERROR: {} is not a valid SimBA meta hyper-parameters file.'.format(config_name)
-            print(error_msg)
-            raise ValueError(error_msg)
+            raise InvalidHyperparametersFileError(msg='SIMBA ERROR: {} is not a valid SimBA meta hyper-parameters file.'.format(config_name))
         self.meta = {}
         for m in meta_df.columns:
             self.meta[m] = meta_df[m][0]
@@ -437,17 +441,26 @@ class MachineModelSettingsPopUp(object):
             self.calc_shap_scores_var.set(value=True)
             self.shap_present.set_state(NORMAL)
             self.shap_absent.set_state(NORMAL)
+            self.shap_absent.set_state(NORMAL)
             self.shap_present.entry_set(val=self.meta['shap_target_present_no'])
             self.shap_absent.entry_set(val=self.meta['shap_target_absent_no'])
         else:
             self.calc_shap_scores_var.set(value=False)
             self.shap_present.set_state(DISABLED)
             self.shap_absent.set_state(DISABLED)
+            self.shap_save_it_dropdown.enable()
 
         if 'train_test_split_type' in self.meta.keys():
             self.train_test_type_dropdown.setChoices(self.meta['train_test_split_type'])
         else:
             self.train_test_type_dropdown.setChoices(Options.TRAIN_TEST_SPLIT.value[0])
+        if 'shap_save_iteration' in self.meta.keys():
+            self.shap_save_it_dropdown.setChoices(self.meta['shap_save_iteration'])
+        if 'partial_dependency' in self.meta.keys():
+            if self.meta['partial_dependency'] in Options.RUN_OPTIONS_FLAGS.value:
+                self.partial_dependency_var.set(value=True)
+        else:
+            self.shap_save_it_dropdown.setChoices('None')
         if 'class_weights' in self.meta.keys():
             self.class_weights_dropdown.setChoices(self.meta['class_weights'])
             if self.meta['class_weights'] == 'custom':
@@ -488,6 +501,8 @@ class MachineModelSettingsPopUp(object):
                                            'generate_shap_scores',
                                            'shap_target_present_no',
                                            'shap_target_absent_no',
+                                           'shap_save_iteration',
+                                           'partial_dependency',
                                            'class_weights',
                                            'class_custom_weights']
 
