@@ -1,4 +1,4 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
 import configparser
 from simba.drop_bp_cords import (get_fn_ext,
@@ -24,12 +24,19 @@ from configparser import (ConfigParser,
 import multiprocessing
 from simba.read_config_unit_tests import (check_file_exist_and_readable,
                                           read_config_entry,
-                                          check_int,
                                           read_config_file,
                                           check_if_filepath_list_is_empty)
-from simba.enums import ReadConfig, Formats, Dtypes, Paths
+from simba.enums import ReadConfig, Dtypes, Paths
+from simba.extract_frames_fast import video_to_frames
+from simba.utils.errors import (InvalidVideoFileError,
+                                NotDirectoryError,
+                                NoFilesFoundError,
+                                DirectoryExistError,
+                                InvalidFileTypeError,
+                                CountError)
 import shutil
 import platform
+import logging
 import pickle
 import pathlib
 from datetime import datetime
@@ -41,7 +48,7 @@ import simba
 
 def get_video_meta_data(video_path: str):
     """
-    Helper to read video meta data (fps, resolution, frame cnt etc.) from video file.
+    Helper to read video metadata (fps, resolution, frame cnt etc.) from video file.
 
     Parameters
     ----------
@@ -71,8 +78,7 @@ def get_video_meta_data(video_path: str):
     video_data['frame_count'] = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
     for k, v in video_data.items():
         if v == 0:
-            print('SIMBA WARNING: Video {} has {} of {}.'.format(video_data['video_name'], k, str(v)))
-            raise ValueError('SIMBA WARNING: Video {} has {} of {}.'.format(video_data['video_name'], k, str(v)))
+            raise InvalidVideoFileError(msg='SIMBA WARNING: Video {} has {} of {}.'.format(video_data['video_name'], k, str(v)))
     video_data['resolution_str'] = str('{} x {}'.format(video_data['width'], video_data['height']))
     video_data['video_length_s'] = int(video_data['frame_count'] / video_data['fps'])
     return video_data
@@ -274,13 +280,13 @@ def line_length_numba_to_static_location(left_ear_array: np.array,
 
     Parameters
     ----------
-    left_ear_array: np.array
+    left_ear_array: array
         left ear coordinates of observing animal.
-    right_ear_array: np.array
+    right_ear_array: array
         right ear coordinates of observing animal.
-    nose_array: np.array
+    nose_array: array
         nose coordinates of observing animal.
-    target_array: np.array
+    target_array: array
         The location of the target coordinates.
 
     Returns
@@ -344,6 +350,75 @@ def find_video_of_file(video_dir: str,
     return return_path
 
 
+def extract_frames_from_all_videos_in_directory(config_path: str,
+                                                directory: str) -> None:
+    """
+    Helper to extract all frames from all videos in a directory. The results are saved in the project_folder/frames/input
+    directory of the SimBa project
+
+    Parameters
+    ----------
+    config_path: str
+        path to SimBA project config file in Configparser format
+    directory: str
+        path to file or folder containing videos in mp4 and/or avi format
+
+    :return
+    ----------
+    list
+
+    Examples
+    ----------
+    >>> extract_frames_from_all_videos_in_directory(config_path='project_folder/project_config.ini', source='/MyVideoDirectory/')
+    """
+    timer = SimbaTimer()
+    timer.start_timer()
+    video_paths, video_types = [], ['.avi', '.mp4']
+    files_in_folder = glob.glob(directory + '/*')
+    for file_path in files_in_folder:
+        _, _, ext = get_fn_ext(filepath=file_path)
+        if ext.lower() in video_types:
+            video_paths.append(file_path)
+    if len(video_paths) == 0:
+        raise NoFilesFoundError(msg='SIMBA ERROR: 0 video files in mp4 or avi format found in {}'.format(directory))
+    config = read_config_file(config_path)
+    project_path = read_config_entry(config, 'General settings', 'project_path', data_type='folder_path')
+
+    print('Extracting frames for {} videos into project_folder/frames/input directory...'.format(len(video_paths)))
+    for video_path in video_paths:
+        dir_name, video_name, ext = get_fn_ext(video_path)
+        save_path = os.path.join(project_path, 'frames', 'input', video_name)
+        if not os.path.exists(save_path): os.makedirs(save_path)
+        else: print(f'Frames for video {video_name} already extracted. SimBA is overwriting prior frames...')
+        video_to_frames(video_path, save_path, overwrite=True, every=1, chunk_size=1000)
+    timer.stop_timer()
+    print(f'SIMBA COMPLETE: Frames created for {str(len(video_paths))} videos (elapsed time: {timer.elapsed_time_str}s).')
+
+
+
+def copy_img_folder(config_path: str, source: str) -> None:
+    """
+    Copy directory of png files to the SimBA project. The directory is stored in the project_folder/frames/input
+    folder of the SimBA project.
+    """
+    timer = SimbaTimer()
+    timer.start_timer()
+    if not os.path.isdir(source):
+        raise NotDirectoryError(msg=f'SIMBA ERROR: source {source} is not a directory.')
+    if len(glob.glob(source + '/*.png')) == 0:
+        raise NoFilesFoundError(msg=f'SIMBA ERROR: source {source} does not contain any .png files.')
+    input_basename = os.path.basename(source)
+    config = read_config_file(config_path)
+    project_path = read_config_entry(config, ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value, data_type='folder_path')
+    input_frames_dir = os.path.join(project_path, Paths.INPUT_FRAMES_DIR.value)
+    destination = os.path.join(input_frames_dir, input_basename)
+    if os.path.isdir(destination):
+        raise DirectoryExistError(msg=f'SIMBA ERROR: {destination} already exist in SimBA project.')
+    print(f'Importing image files for {input_basename}...')
+    shutil.copytree(source, destination)
+    timer.stop_timer()
+    print(f'SIMBA COMPLETE: {destination} imported to SimBA project (elapsed time {timer.elapsed_time_str}s)')
+
 def smooth_data_gaussian(config: configparser.ConfigParser,
                          file_path: str,
                          time_window_parameter: int):
@@ -442,13 +517,13 @@ def smooth_data_savitzky_golay(config: configparser.ConfigParser,
     try:
         time_window_parameter = int(time_window_parameter)
     except:
-        print(
-            'Savitzky-Golay smoothing failed for video {}. The specified time window parameter {} can not be interpreted as an integer.'.format(
-                str(os.path.basename(file_path)), str(time_window_parameter)))
+        print('Savitzky-Golay smoothing failed for video {}. The specified time window parameter {} can not be interpreted as an integer.'.format(str(os.path.basename(file_path)), str(time_window_parameter)))
     _, filename, _ = get_fn_ext(file_path)
     project_dir = config.get(ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value)
     video_dir = os.path.join(project_dir, 'videos')
     video_file_path = find_video_of_file(video_dir, filename)
+    if not video_file_path:
+        raise NoFilesFoundError(msg=f'SIMBA ERROR: Import video for {filename} to perform Savitzky-Golay smoothing')
     file_format = get_workflow_file_format(config)
     cap = cv2.VideoCapture(video_file_path)
     video_fps = int(cap.get(cv2.CAP_PROP_FPS))
@@ -793,6 +868,7 @@ def detect_bouts(data_df: pd.DataFrame,
             endFrameList.append(endFrame)
             startFrameLst.append(bout_start_frm)
 
+    startFrameLst = [x-1 for x in startFrameLst]
     return pd.DataFrame(list(zip(nameList, startTimeList, endTimeList, startFrameLst, endFrameList, boutsList)),
                         columns=['Event', 'Start_time', 'End Time', 'Start_frame', 'End_frame', 'Bout_time'])
 
@@ -902,6 +978,8 @@ def split_file_path(path: str):
             path_parts.insert(0, parts[1])
     return path_parts
 
+def str_2_bool(input_str: str):
+  return input_str.lower() in ("yes", "true", "1")
 
 def convert_parquet_to_csv(directory: str):
     """
@@ -914,12 +992,10 @@ def convert_parquet_to_csv(directory: str):
     """
 
     if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError
+        raise NotDirectoryError(msg='SIMBA ERROR: {} is not a valid directory'.format(directory))
     files_found = glob.glob(directory + '/*.parquet')
     if len(files_found) < 1:
-        print('SIMBA ERROR: No parquet files (with .parquet file ending) found in the {} directory'.format(directory))
-        raise ValueError
+        raise NoFilesFoundError('SIMBA ERROR: No parquet files (with .parquet file ending) found in the {} directory'.format(directory))
     for file_cnt, file_path in enumerate(files_found):
         print('Reading in {} ...'.format(os.path.basename(file_path)))
         df = pd.read_parquet(file_path)
@@ -945,12 +1021,10 @@ def convert_csv_to_parquet(directory: str):
     None
     """
     if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError
+        raise NotDirectoryError(msg='SIMBA ERROR: {} is not a valid directory'.format(directory))
     files_found = glob.glob(directory + '/*.csv')
     if len(files_found) < 1:
-        print('SIMBA ERROR: No parquet files (with .csv file ending) found in the {} directory'.format(directory))
-        raise ValueError
+        raise NoFilesFoundError(msg='SIMBA ERROR: No parquet files (with .csv file ending) found in the {} directory'.format(directory))
     print('Converting {} files...'.format(str(len(files_found))))
     for file_cnt, file_path in enumerate(files_found):
         print('Reading in {} ...'.format(os.path.basename(file_path)))
@@ -995,10 +1069,7 @@ def archive_processed_files(config_path: str,
                 file_lst.append(os.path.join(subdirectory, file_path))
 
     if len(file_lst) < 1:
-        print(
-            'SIMBA ERROR: No data files located in your project_folder/csv sub-directories in the worflow file format {}'.format(
-                file_type))
-        raise ValueError()
+        raise NoFilesFoundError(msg='SIMBA ERROR: No data files located in your project_folder/csv sub-directories in the worflow file format {}'.format(file_type))
 
     for file_path in file_lst:
         file_folder = os.path.dirname(file_path)
@@ -1067,6 +1138,13 @@ def get_named_colors():
             'lime',
             'coral',
             'deeppink',
+            'darkgoldenrod',
+            'olive',
+            'seagreen',
+            'dodgerblue',
+            'springgreen',
+            'firebrick',
+            'indigo'
             'white']
 
 
@@ -1193,18 +1271,15 @@ def copy_single_video_to_project(simba_ini_path: str,
     timer = SimbaTimer()
     timer.start_timer()
     _, file_name, file_ext = get_fn_ext(source_path)
+    check_file_exist_and_readable(file_path=source_path)
     print('Copying video {} file...'.format(file_name))
     if file_ext[1:].lower().strip() not in allowed_video_formats:
-        print(
-            'SIMBA ERROR: SimBA works best with avi and mp4 videofiles. Or please convert your videos to mp4 or avi to continue before importing it. ')
+        print('SIMBA ERROR: SimBA works best with avi and mp4 videofiles. Or please convert your videos to mp4 or avi to continue before importing it. ')
         raise ValueError()
     new_filename = os.path.join(file_name + file_ext)
     destination = os.path.join(os.path.dirname(simba_ini_path), 'videos', new_filename)
     if os.path.isfile(destination):
-        print(
-            'SIMBA ERROR: {} already exist in SimBA project. To import, delete this video file before importing the new video file with the same name.'.format(
-                file_name))
-        raise FileExistsError()
+        raise DirectoryExistError(msg='SIMBA ERROR: {} already exist in SimBA project. To import, delete this video file before importing the new video file with the same name.'.format(file_name))
     else:
         timer.stop_timer()
         shutil.copy(source_path, destination)
@@ -1239,9 +1314,7 @@ def copy_multiple_videos_to_project(config_path: str,
     video_path_lst = find_all_videos_in_directory(directory=source, video_formats=(file_type))
     video_path_lst = [os.path.join(source, x) for x in video_path_lst]
     if len(video_path_lst) == 0:
-        print('SIMBA ERROR: No videos found in {} directory'.format(source))
-        raise ValueError()
-
+        raise NoFilesFoundError(msg='SIMBA ERROR: No videos found in {} directory in file-type {}'.format(source, file_type))
     destination_dir = os.path.join(os.path.dirname(config_path), 'videos')
     for file_cnt, file_path in enumerate(video_path_lst):
         timer = SimbaTimer()
@@ -1354,20 +1427,18 @@ def run_user_defined_feature_extraction_class(file_path: str,
     file_path: str
         Path to .py file holding user-defined feature extraction class
     config_path: str
-        Path to SimBA cproject config file
+        Path to SimBA project config file
     """
 
     check_file_exist_and_readable(file_path=file_path)
     file_dir, file_name, file_extension = get_fn_ext(filepath=file_path)
     if file_extension != '.py':
-        print(f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) is not a .py file-extension')
-        raise ImportError(f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) is not a .py file-extension')
+        raise InvalidFileTypeError(msg=f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) is not a .py file-extension')
     parsed = ast.parse(Path(file_path).read_text())
     classes = [n for n in parsed.body if isinstance(n, ast.ClassDef)]
     class_name = [x.name for x in classes]
     if len(class_name) < 1:
-        print(f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) contains no python classes')
-        raise ImportError(f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) contains no python classes')
+        raise CountError(msg=f'SIMBA ERROR: The user-defined feature extraction file ({file_path}) contains no python classes')
     else:
         class_name = class_name[0]
     spec = importlib.util.spec_from_file_location(class_name, file_path)
@@ -1378,6 +1449,38 @@ def run_user_defined_feature_extraction_class(file_path: str,
     print(f'Running user-defined {class_name} feature extraction file...')
     user_class(config_path=config_path)
 
+def find_animal_name_from_body_part_name(bp_name: str, bp_dict: dict) -> str:
+    for animal_name, animal_bps in bp_dict.items():
+        if bp_name in [x[:-2] for x in animal_bps['X_bps']]:
+            return animal_name
+
+def create_logger(path: str):
+    logger = logging.getLogger()
+    logger.setLevel(logging.INFO)
+    handler = logging.FileHandler(filename=path, encoding='utf-8')  # or whatever
+    handler.setFormatter(logging.Formatter('%(asctime)s %(levelname)s %(message)s'))
+    logger.addHandler(handler)
+
+
+    #
+    #
+    # logger = logging.getLogger("test")
+    # logger.setLevel(level=logging.WARNING)
+    # log_format = logging.Formatter(fmt=f"%(levelname)s %(asctime)s (%(relativeCreated)d) \t %(pathname)s %(funcName)s L%(lineno)s - %(message)s", datefmt="%Y-%m-%d %H:%M:%S")
+    # log_file = logging.FileHandler(filename=path)
+    # log_file.setFormatter(log_format)
+    # log_file.setLevel(level=logging.INFO)
+    # logger.addHandler(log_file)
+    #
+    #
+    #
+
+# logging.basicConfig(filename='example.log',level=logging.DEBUG)
+
+
+
+
+
 
 
 # run_user_defined_feature_extraction_class(file_path='/Users/simon/Desktop/envs/simba_dev/simba/features_scripts/misc/fish_feature_extractor.py',
