@@ -1,53 +1,50 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
 import configparser
-
 import trafaret as t
 import os
 import pandas as pd
 from simba.enums import ReadConfig, Dtypes, Formats
 from configparser import ConfigParser, MissingSectionHeaderError
+from simba.utils.errors import (NoFilesFoundError,
+                                IntegerError,
+                                InvalidInputError,
+                                StringError,
+                                FloatError,
+                                NotDirectoryError,
+                                MissingProjectConfigEntryError,
+                                CorruptedFileError,
+                                ColumnNotFoundError)
 
 def check_int(name, value, max_value=None, min_value=None):
     try:
         t.Int().check(value)
     except t.DataError as e:
-        print('SIMBA VALUE ERROR: {} {} {}'.format(name, str(value), e.as_dict()))
-        raise ValueError(f'SIMBA VALUE ERROR: {name} should be an integer number in SimBA, but is set to {str(value)}')
+        print(e)
+        raise IntegerError(msg=f'{name} should be an integer number in SimBA, but is set to {str(value)}')
     if (min_value != None):
         if int(value) < min_value:
-            print(('SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
-                                                                                              str(value))))
-            raise ValueError(
-                f'SIMBA VALUE ERROR: {name} should be more than, or equal {str(min_value)}. It is set to {str(value)}')
+            raise IntegerError(msg=f'{name} should be MORE THAN OR EQUAL to {str(min_value)}. It is set to {str(value)}')
     if (max_value != None):
         if int(value) > max_value:
-            print(('SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
-                                                                                              str(value))))
-            raise ValueError(
-                f'SIMBA VALUE ERROR: {name} should be less than, or equal {str(max_value)}. It is set to {str(value)}')
+            raise IntegerError(msg=f'{name} should be LESS THAN OR EQUAL to {str(max_value)}. It is set to {str(value)}')
 
 def check_if_valid_input(name, input, options):
     if input not in options:
-        error_msg = f'SIMBA VALUE ERROR: {name} is set to {str(input)}, which is an invalid setting. OPTIONS {options}'
-        print(error_msg)
-        raise ValueError(error_msg)
+        raise InvalidInputError(msg=f'{name} is set to {str(input)}, which is an invalid setting. OPTIONS {options}')
     else:
         pass
 
-
 def check_str(name, value, options=(), allow_blank=False):
     try:
         t.String(allow_blank=allow_blank).check(value)
     except t.DataError as e:
-        print('{} {} {}'.format(name, str(value), e.as_dict()))
-        raise ValueError('SIMBA VALUE ERROR: {} should be an string in SimBA, but is set to {}'.format(name, str(value)))
+        print(e)
+        raise StringError(msg=f'{name} should be an string in SimBA, but is set to {str(value)}')
+
     if len(options) > 0:
         if value not in options:
-            print(('SIMBA VALUE ERROR: {} is set to {} in SimBA, but this is not a valid option {}'.format(name, str(value),
-                                                                                                     options)))
-            raise ValueError(
-                f'SIMBA VALUE ERROR: {name} is set to {str(value)} in SimBA, but this is not a valid option {options}')
+            raise StringError(msg=f'{name} is set to {str(value)} in SimBA, but this is not a valid option: {options}')
         else:
             pass
     else:
@@ -61,22 +58,14 @@ def check_float(name: str,
     try:
         t.Float().check(value)
     except t.DataError as e:
-        print('{} {} {}'.format(name, str(value), e.as_dict()))
-        print('SIMBA VALUE ERROR: {} should be a float number in SimBA, but is set to {}'.format(name, str(value)))
-        raise ValueError('SIMBA VALUE ERROR: {} should be a float in SimBA, but is set to {}'.format(name, str(value)))
+        print(e)
+        raise FloatError(msg=f'{name} should be a float number in SimBA, but is set to {str(value)}')
     if (min_value != None):
         if float(value) < min_value:
-            print('SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
-                                                                                             str(value)))
-            raise ValueError('SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
-                                                                                             str(value)))
+            raise FloatError(msg=f'{name} should be MORE THAN OR EQUAL to {str(min_value)}. It is set to {str(value)}')
     if (max_value != None):
         if float(value) > max_value:
-            print('SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
-                                                                                             str(value)))
-            raise ValueError('SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
-                                                                                             str(value)))
-
+            raise FloatError(msg=f'{name} should be LESS THAN OR EQUAL to {str(max_value)}. It is set to {str(value)}')
 
 def read_config_entry(config: ConfigParser,
                       section: str,
@@ -95,26 +84,23 @@ def read_config_entry(config: ConfigParser,
             elif data_type == 'folder_path':
                 value = config.get(section, option)
                 if not os.path.isdir(value):
-                    print('VALUE ERROR: SimBA is looking for the folder {} but it does not exist.'.format(value))
-                    raise ValueError
+                    raise NotDirectoryError(msg=f'The SimBA config file includes paths to a folder ({value}) that does not exist.')
             if options != None:
                 if value not in options:
-                    print(('VALUE ERROR: {} is set to {} in SimBA, but this is not among the valid options ({})'.format(option, str(value), options)))
-                    raise ValueError
+                    raise InvalidInputError(msg=f'{option} is set to {str(value)} in SimBA, but this is not among the valid options: ({options})')
                 else:
                     return value
             return value
         elif default_value != None:
             return default_value
         else:
-            print('VALUE ERROR: SimBA could not find an entry for option {} under section {} in the project_config.ini. Please specify the settings in the settings menu.'.format(option, section))
-            raise ValueError
+            raise MissingProjectConfigEntryError(msg=f'SimBA could not find an entry for option {option} under section {section} in the project_config.ini. Please specify the settings in the settings menu.')
     except ValueError:
         if default_value != None:
             return default_value
         else:
-            print(('VALUE ERROR: SimBA could not find an entry for option {} under section {} in the project_config.ini. Please specify the settings in the settings menu.'.format(option, section)))
-            raise ValueError
+            raise MissingProjectConfigEntryError(msg=f'SimBA could not find an entry for option {option} under section {section} in the project_config.ini. Please specify the settings in the settings menu.')
+
 
 def read_simba_meta_files(folder_path: str):
     from simba.misc_tools import find_files_of_filetypes_in_directory
@@ -135,29 +121,22 @@ def read_meta_file(meta_file_path):
 
 def check_file_exist_and_readable(file_path: str):
     if not os.path.isfile(file_path):
-        print('SIMBA FILE NOT FOUND ERROR: {} is not a valid file path'.format(file_path))
-        raise FileNotFoundError('SIMBA FILE NOT FOUND ERROR: {} is not a valid file path'.format(file_path))
+        raise NoFilesFoundError(msg=f'{file_path} is not a valid file path')
     elif not os.access(file_path, os.R_OK):
-        print('SIMBA FILE CORRUPTED ERROR: {} is not readable'.format(file_path))
-        raise FileNotFoundError('SIMBA FILE CORRUPTED ERROR: {} is not readable'.format(file_path))
-
+        raise CorruptedFileError(f'{file_path} is not readable')
 
 def read_config_file(ini_path: str):
     config = ConfigParser()
     try:
         config.read(str(ini_path))
     except MissingSectionHeaderError:
-        print('ERROR:  Not a valid project_config file. Please check the project_config.ini path.')
+        print('ERROR: Not a valid project_config file. Please check the project_config.ini path.')
         raise MissingSectionHeaderError
     return config
 
 def check_if_dir_exists(in_dir: str):
     if not os.path.isdir(in_dir):
-        error_msg = 'SIMBA ERROR: {} is not a valid directory'.format(in_dir)
-        print(error_msg)
-        raise NotADirectoryError(error_msg)
-    else:
-        pass
+        raise NotDirectoryError(msg=f'{in_dir} is not a valid directory')
 
 def insert_default_headers_for_feature_extraction(df: pd.DataFrame,
                                                   headers: list,
@@ -177,17 +156,12 @@ def check_that_column_exist(df: pd.DataFrame,
                             column_name: str,
                             file_name: str):
     if column_name not in df.columns:
-        print(f'SIMBA ERROR: Could not find expected column named `{column_name}` within the file representing {file_name}')
-        raise ValueError(f'SIMBA ERROR: Could not find expected column named `{column_name}` within the file representing {file_name}')
-    else:
-        pass
-
+        raise ColumnNotFoundError(column_name=column_name, file_name=file_name)
 
 def check_if_filepath_list_is_empty(filepaths: list,
                                     error_msg: str):
     if len(filepaths) == 0:
-        print(error_msg)
-        raise ValueError(error_msg)
+        raise NoFilesFoundError(msg=error_msg)
     else:
         pass
 
