@@ -5,6 +5,7 @@ from datetime import datetime
 from simba.read_config_unit_tests import (check_if_filepath_list_is_empty,
                                           check_if_dir_exists)
 from simba.misc_tools import check_if_filepath_list_is_empty
+from simba.enums import Formats
 
 
 class KeypointReorganizer(object):
@@ -44,12 +45,10 @@ class KeypointReorganizer(object):
         self.file_format = file_format
         self.files_found = glob.glob(self.data_folder + '/*.' + file_format)
         check_if_filepath_list_is_empty(self.files_found,
-                                        error_msg=f'SIMBA ERROR: {self.data_folder} directory has no {file_format} files.')
-
+                                        error_msg=f'SIMBA ERROR: {self.data_folder} directory contains no {file_format} files.')
         self.datetime = str(datetime.now().strftime('%Y%m%d%H%M%S'))
-        check_if_filepath_list_is_empty(filepaths=self.files_found,
-                                        error_msg='SIMBA ERROR: Zero files found of type {} in the {} directory'.format(file_format, data_folder))
-        if file_format == 'h5':
+
+        if (file_format == Formats.H5.value) and (pose_tool == 'DLC' or 'maDLC'):
             first_df = pd.read_hdf(self.files_found[0])
             self.header_list = list(first_df.columns)
             animal_bp_tuple_list = []
@@ -61,7 +60,7 @@ class KeypointReorganizer(object):
             self.animal_list = [x[0] for x in animal_bp_tuple_list]
             self.bp_list = [x[1] for x in animal_bp_tuple_list]
 
-        if file_format == 'csv':
+        elif (file_format == Formats.CSV.value) and (pose_tool == 'DLC' or 'maDLC'):
             first_df = pd.read_csv(self.files_found[0])
             if first_df.scorer.loc[2] == 'coords':
                 scorer = list(first_df.columns)
@@ -72,13 +71,11 @@ class KeypointReorganizer(object):
                 bodyparts.remove('bodyparts')
                 coords = list(first_df.loc[2, :])
                 coords.remove('coords')
-
                 self.header_list = list(zip(scorer, individuals, bodyparts, coords))
                 animallist = list(zip(individuals, bodyparts))
                 animal_bp_tuple_list = list(OrderedDict.fromkeys(animallist))
                 self.animal_list = [x[0] for x in animal_bp_tuple_list]
                 self.bp_list = [x[1] for x in animal_bp_tuple_list]
-
             else:
                 self.animal_list = None
                 scorer = list(first_df.columns)
@@ -93,6 +90,11 @@ class KeypointReorganizer(object):
                 coords.remove('coords')
                 self.header_list = list(zip(scorer, bodyparts, coords))
 
+        elif (file_format == Formats.CSV.value) and (pose_tool == 'SLEAP'):
+            print('s')
+
+
+
     def perform_reorganization(self,
                                bp_lst: list,
                                animal_list: list = None):
@@ -127,12 +129,14 @@ class KeypointReorganizer(object):
         print('SIMBA COMPLETE: {} new data files with reorganized body-parts saved in {} directory'.format(str(len(self.files_found)), save_directory))
 
 
+#keypoint_reorganizer = KeypointReorganizer(data_folder="/Users/simon/Desktop/envs/troubleshooting/Termites_5/import_h5", pose_tool='SLEAP', file_format='csv')
+
+
+
+
+
+
 #keypoint_reorganizer = KeypointReorganizer(data_folder="/Users/simon/Desktop/envs/troubleshooting/Termites_5/import_h5", pose_tool='SLEAP', file_format='SLEAP H5')
-
-
-
-
-
 #keypoint_reorganizer = KeypointReorganizer(data_folder="/Users/simon/Desktop/troubleshooting/B1-MS_US/el_import", pose_tool='maDLC', file_format='h5')
 #keypoint_reorganizer.perform_reorganization(animal_list=['UM', 'LM', 'LM', 'UM', 'LM', 'UM', 'LM', 'LM', 'UM', 'LM', 'UM', 'UM', 'UM', 'UM', 'LM', 'LM'], bp_lst=['Nose', 'Tail_base', 'Tail_base', 'Lateral_right', 'Ear_right', 'Center', 'Nose', 'Ear_left', 'Ear_right', 'Center', 'Tail_end', 'Ear_left', 'Tail_base', 'Lateral_left', 'Tail_end', 'Lateral_right'])
 
