@@ -12,9 +12,9 @@ from simba.roi_tools.ROI_size_calculations import (rectangle_size_calc,
                                                    circle_size_calc,
                                                    polygon_size_calc)
 from simba.misc_tools import get_color_dict
-from simba.features_scripts.unit_tests import read_video_info
+from simba.feature_extractors.unit_tests import read_video_info
 from simba.drop_bp_cords import get_fn_ext
-from simba.features_scripts.unit_tests import read_video_info_csv
+from simba.feature_extractors.unit_tests import read_video_info_csv
 from simba.enums import Paths, ReadConfig
 
 
