@@ -6,7 +6,7 @@ from simba.roi_tools.ROI_define import ROI_definitions
 from simba.roi_tools.ROI_reset import reset_video_ROIs
 from simba.roi_tools.ROI_multiply import multiply_ROIs
 from simba.enums import ReadConfig
-
+from simba.utils.errors import NoFilesFoundError
 
 class ROI_menu:
     def __init__(self, config_path, new_roi=True):
@@ -25,8 +25,7 @@ class ROI_menu:
             if i.endswith(('.avi', '.mp4', '.mov', 'flv')):
                 self.filesFound.append(i)
         if len(self.filesFound) == 0:
-            print('SIMBA ERROR: No videos found the SimBA project (no avi, mp4, mov, flv files in the project_folder/videos directory)')
-            raise FileNotFoundError('SIMBA ERROR: No videos found the SimBA project (no avi, mp4, mov, flv files in the project_folder/videos directory)')
+            raise NoFilesFoundError('No videos found the SimBA project (no avi, mp4, mov, flv files in the project_folder/videos directory)')
 
         maxname = max(self.filesFound, key=len)
         self.roimenu = Toplevel()
