@@ -1,9 +1,13 @@
+
+from tkinter import *
 import os
 from configparser import ConfigParser
 import pandas as pd
 from simba.drop_bp_cords import get_fn_ext
 from simba.enums import ReadConfig, Keys, Paths
-from tkinter import *
+from simba.read_config_unit_tests import read_config_file
+from simba.utils.errors import NoROIDataError
+from simba.enums import Formats
 
 def reset_video_ROIs(config_path, filename):
 
@@ -15,7 +19,7 @@ def reset_video_ROIs(config_path, filename):
     logFolderPath = os.path.join(vidInfPath, 'logs')
     ROIcoordinatesPath = os.path.join(logFolderPath, Paths.ROI_DEFINITIONS.value)
     if not os.path.isfile(ROIcoordinatesPath):
-        raise FileNotFoundError('Cannot delete ROI definitions: no definitions exist to delete')
+        raise NoROIDataError(msg='Cannot delete ROI definitions: no definitions exist to delete')
 
     else:
         rectanglesInfo = pd.read_hdf(ROIcoordinatesPath, key=Keys.ROI_RECTANGLES.value)
@@ -44,20 +48,19 @@ def reset_video_ROIs(config_path, filename):
     print('Deleted ROI record: ' + str(file_name_wo_ext))
     store.close()
 
-def delete_all_ROIs(config_path):
+def delete_all_ROIs(config_path: str):
 
     def delete_file(config_path):
-        config = ConfigParser()
-        configFile = str(config_path)
-        config.read(configFile)
+        config = read_config_file(ini_path=config_path)
         project_path = config.get(ReadConfig.GENERAL_SETTINGS.value, ReadConfig.PROJECT_PATH.value)
-        ROIcoordinatesPath = os.path.join(project_path, 'logs', Paths.ROI_DEFINITIONS.value)
-        if os.path.isfile(ROIcoordinatesPath):
-            os.remove(ROIcoordinatesPath)
-            print('All ROI definitions deleted in this SimBA project')
+        roi_data_path = os.path.join(project_path, 'logs', Paths.ROI_DEFINITIONS.value)
+
+        if not os.path.isfile(roi_data_path):
+            raise NoROIDataError(msg=f'No ROI definitions exist in this SimBA project. Expected file at path {roi_data_path}')
         else:
-            print('No ROI definitions exist in this SimBA project.')
-        close_window()
+            os.remove(roi_data_path)
+            close_window()
+            print('SIMBA COMPLETE: All ROI definitions deleted in this SimBA project')
 
     def close_window():
         delete_confirm_win.destroy()
@@ -67,7 +70,7 @@ def delete_all_ROIs(config_path):
     delete_confirm_win.minsize(200, 200)
 
     question_frame = LabelFrame(delete_confirm_win, text='Confirm', font=("Arial", 16, "bold"), padx=5, pady=5)
-    question_lbl = Label(question_frame, text="Do you want to delete all defined ROIs in the project?", font=("Arial", 10))
+    question_lbl = Label(question_frame, text="Do you want to delete all defined ROIs in the project?", font=Formats.LABELFRAME_HEADER_FORMAT.value)
 
     yes_button = Button(question_frame, text='YES', fg='black', command=lambda: delete_file(config_path))
     no_button = Button(question_frame, text='NO', fg='black', command=lambda: close_window())
