@@ -1,8 +1,5 @@
 __author__ = "Simon Nilsson", "JJ Choong"
-
-import pandas as pd
-
-from simba.features_scripts.unit_tests import (read_video_info_csv,
+from simba.feature_extractors.unit_tests import (read_video_info_csv,
                                                read_video_info)
 from simba.read_config_unit_tests import (read_config_entry,
                                           read_config_file,
@@ -18,6 +15,7 @@ import os, glob
 from copy import deepcopy
 import pickle
 import numpy as np
+from simba.utils.errors import NoFilesFoundError
 
 class RunModel(object):
 
@@ -58,8 +56,7 @@ class RunModel(object):
         self.model_dict = get_model_info(self.config, self.model_cnt)
         self.files_found = glob.glob(self.files_in_dir + '/*.' + self.file_type)
         if len(self.files_found) == 0:
-            print('SIMBA ERROR: Zero files found in the project_folder/csv/features_extracted directory. Create features before running classifier.')
-            raise FileNotFoundError('SIMBA ERROR: Zero files found in the project_folder/csv/features_extracted directory. Create features before running classifier.')
+            raise NoFilesFoundError('Zero files found in the project_folder/csv/features_extracted directory. Create features before running classifier.')
         print('Analyzing {} file(s) with {} classifier(s)'.format(str(len(self.files_found)), str(len(self.model_dict))))
         self.timer = SimbaTimer()
         self.timer.start_timer()
@@ -74,6 +71,8 @@ class RunModel(object):
             _, px_per_mm, fps = read_video_info(self.vid_info_df, file_name)
             out_df = deepcopy(in_df)
             for m, m_hyp in self.model_dict.items():
+                if not os.path.isfile(m_hyp['model_path']):
+                    raise NoFilesFoundError(msg=f"{m_hyp['model_path']} is not a VALID model file path")
                 clf = pickle.load(open(m_hyp['model_path'], 'rb'))
                 probability_column = 'Probability_' + m_hyp['model_name']
                 try:
