@@ -3,12 +3,13 @@ from simba.read_config_unit_tests import read_config_file, read_config_entry, ch
 import os
 from simba.misc_tools import check_multi_animal_status
 from simba.drop_bp_cords import getBpNames, create_body_part_dictionary
-from simba.ROI_analyzer import ROIAnalyzer
-from simba.ROI_feature_analyzer import ROIFeatureCreator
+from simba.roi_tools.ROI_analyzer import ROIAnalyzer
+from simba.roi_tools.ROI_feature_analyzer import ROIFeatureCreator
 from simba.timebins_movement_analyzer import TimeBinsMovementAnalyzer
 from simba.movement_processor import MovementProcessor
-from simba.ROI_time_bin_calculator import ROITimebinCalculator
+from simba.roi_tools.ROI_time_bin_calculator import ROITimebinCalculator
 from simba.enums import ReadConfig, Formats, Dtypes, Paths
+from simba.utils.errors import NoROIDataError
 
 class SettingsMenu(object):
 
@@ -107,6 +108,14 @@ class SettingsMenu(object):
         self.time_bin_lbl.grid(row=0, column=0)
         self.time_bin_entry.grid(row=0, column=1)
 
+    def create_plot_tick_box(self):
+        self.lbl_frm_cnt += 1
+        self.plots_frm = LabelFrame(self.second_choice_frm, text="Plots", font=Formats.LABELFRAME_HEADER_FORMAT.value)
+        self.plots_var = BooleanVar()
+        self.plots_cb = Checkbutton(self.plots_frm, text='Create plots', variable=self.plots_var)
+        self.plots_frm.grid(row=self.lbl_frm_cnt, column=0, sticky=NW)
+        self.plots_cb.grid(row=0, column=0, sticky=NW)
+
     def display_second_choice_frm(self):
         if hasattr(self, 'second_choice_frm'):
             self.second_choice_frm.destroy()
@@ -122,8 +131,7 @@ class SettingsMenu(object):
 
         if self.title == 'APPEND ROI FEATURES':
             if not os.path.isfile(self.roi_definitions_path):
-                print('SIMBA ERROR: No ROIs have been defined. Please define ROIs before appending ROI-based features')
-                raise FileNotFoundError()
+                raise NoROIDataError(msg='SIMBA ERROR: No ROIs have been defined. Please define ROIs before appending ROI-based features')
             self.create_choose_body_parts_frm()
             self.create_run_btn()
 
@@ -136,6 +144,7 @@ class SettingsMenu(object):
             self.create_choose_body_parts_frm()
             self.create_time_bin_entry()
             self.create_run_btn()
+            self.create_plot_tick_box()
 
         if self.title == 'TIME BINS: ANALYZE ROI':
             self.create_choose_body_parts_frm()
@@ -147,13 +156,21 @@ class SettingsMenu(object):
 
     def run_analysis(self):
         if self.title == 'ROI ANALYSIS':
-            self.config.set(ReadConfig.ROI_SETTINGS.value, ReadConfig.ROI_ANIMAL_CNT.value, str(self.animal_cnt.get()))
-            check_float(name='Probability threshold', value=self.probability_bp_entry_box.get())
-            self.config.set(ReadConfig.ROI_SETTINGS.value, ReadConfig.PROBABILITY_THRESHOLD.value, str(self.probability_bp_entry_box.get()))
+            settings = {}
+            check_float(name='Probability threshold', value=self.probability_bp_entry_box.get(), min_value=0.00, max_value=1.00)
+            settings['threshold'] = float(self.probability_bp_entry_box.get())
+            settings['body_parts'] = {}
             for cnt, (name, data) in enumerate(self.animals_dict.items()):
-                self.config.set('ROI settings', 'animal_{}_bp'.format(str(cnt + 1)), str(self.animals_dict[name]['var'].get()))
+                settings['body_parts'][f'animal_{str(cnt+1)}_bp'] = str(self.animals_dict[name]['var'].get())
+            for cnt, (name, data) in enumerate(self.animals_dict.items()):
+                self.config.set('ROI settings', f'animal_{str(cnt+1)}_bp', str(self.animals_dict[name]['var'].get()))
+            self.config.set(ReadConfig.ROI_SETTINGS.value, ReadConfig.ROI_ANIMAL_CNT.value, str(self.animal_cnt.get()))
+            self.config.set(ReadConfig.ROI_SETTINGS.value, ReadConfig.PROBABILITY_THRESHOLD.value, str(self.probability_bp_entry_box.get()))
             self.update_config()
-            roi_analyzer = ROIAnalyzer(ini_path=self.config_path, data_path='outlier_corrected_movement_location', calculate_distances=self.calculate_distance_moved_var.get())
+            roi_analyzer = ROIAnalyzer(ini_path=self.config_path,
+                                       data_path='outlier_corrected_movement_location',
+                                       calculate_distances=self.calculate_distance_moved_var.get(),
+                                       settings=settings)
             roi_analyzer.read_roi_dfs()
             roi_analyzer.analyze_ROIs()
             roi_analyzer.save_data()
@@ -180,14 +197,14 @@ class SettingsMenu(object):
             for cnt, (name, data) in enumerate(self.animals_dict.items()):
                 self.config.set(ReadConfig.PROCESS_MOVEMENT_SETTINGS.value, 'animal_{}_bp'.format(str(cnt + 1)), str(self.animals_dict[name]['var'].get()))
             self.update_config()
-            time_bin_movement_analyzer = TimeBinsMovementAnalyzer(config_path=self.config_path, bin_length=int(self.time_bin_val.get()))
+            time_bin_movement_analyzer = TimeBinsMovementAnalyzer(config_path=self.config_path, bin_length=int(self.time_bin_val.get()), plots=self.plots_var.get())
             time_bin_movement_analyzer.analyze_movement()
 
         if self.title == 'TIME BINS: ANALYZE ROI':
             check_int(name='Time bin', value=self.time_bin_val.get())
             self.config.set(ReadConfig.ROI_SETTINGS.value, ReadConfig.ROI_ANIMAL_CNT.value, str(self.animal_cnt.get()))
             for cnt, (name, data) in enumerate(self.animals_dict.items()):
-                self.config.set(ReadConfig.ROI_SETTINGS.value, 'animal_{}_bp'.format(str(cnt + 1)),str(self.animals_dict[name]['var'].get()))
+                self.config.set(ReadConfig.ROI_SETTINGS.value, f'{name}', str(self.animals_dict[name]['var'].get()))
             self.update_config()
             roi_time_bin_calculator = ROITimebinCalculator(config_path=self.config_path, bin_length=self.time_bin_val.get())
             roi_time_bin_calculator.analyze_time_bins()
@@ -196,7 +213,7 @@ class SettingsMenu(object):
 
 
 
-# test = SettingsMenu(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini', title='ROI ANALYSIS')
+# test = SettingsMenu(config_path='/Users/simon/Desktop/envs/troubleshooting/two_animals_16bp_032023/project_folder/project_config.ini', title='ROI ANALYSIS')
 # test.setting_main.mainloop()
 
 # test = SettingsMenu(config_path='/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini', title='APPEND ROI FEATURES')
