@@ -1,26 +1,21 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
 import pandas as pd
-from simba.read_config_unit_tests import (read_config_entry,
-                                          read_config_file,
-                                          check_int,
-                                          check_if_filepath_list_is_empty,
-                                          read_project_path_and_file_type)
-from simba.misc_tools import (detect_bouts,
-                              SimbaTimer)
-from simba.features_scripts.unit_tests import read_video_info_csv, read_video_info
-from simba.train_model_functions import get_all_clf_names
-from datetime import datetime
+from simba.read_config_unit_tests import (check_int,
+                                          check_if_filepath_list_is_empty)
+from simba.misc_tools import detect_bouts
+from simba.feature_extractors.unit_tests import read_video_info
 import os, glob
 from simba.rw_dfs import read_df
-from simba.enums import ReadConfig, Paths, Dtypes
 from simba.drop_bp_cords import get_fn_ext
 from collections import defaultdict
+from simba.mixins.config_reader import ConfigReader
+from simba.utils.errors import NoChoosenMeasurementError
 
-class TimeBinsClf(object):
+class TimeBinsClf(ConfigReader):
 
     """
-    Class for aggregating classification results into time-bins. Results are stored in
+    Class for aggregating classification results into user-defined time-bins. Results are stored in
     the ``project_folder/logs`` directory of the SimBA project`
 
     Parameters
@@ -50,25 +45,16 @@ class TimeBinsClf(object):
                  measurements: list,
                  classifiers: list):
 
+        super().__init__(config_path=config_path)
         if len(measurements) == 0:
-            print('SIMBA ERROR: Please select at least ONE aggregate statistic measurement.')
-            raise ValueError('SIMBA ERROR: Please select at least ONE aggregate statistic measurement.')
+            raise NoChoosenMeasurementError()
         check_int(name='Bin length', value=bin_length)
-        self.bin_length, self.measurements = int(bin_length), measurements
-        self.classifiers, self.config = classifiers, read_config_file(config_path)
-        self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
-        self.data_in_dir = os.path.join(self.project_path, Paths.MACHINE_RESULTS_DIR.value)
-        self.vid_info_df = read_video_info_csv(os.path.join(self.project_path, Paths.VIDEO_INFO.value))
-        self.datetime = datetime.now().strftime('%Y%m%d%H%M%S')
-        self.target_cnt = read_config_entry(self.config, ReadConfig.SML_SETTINGS.value, ReadConfig.TARGET_CNT.value, data_type=Dtypes.INT.value)
-        self.clf_names = get_all_clf_names(config=self.config, target_cnt=self.target_cnt)
-        self.files_found = glob.glob(self.data_in_dir + '/*.' + self.file_type)
+        self.bin_length, self.measurements, self.classifiers = int(bin_length), measurements, classifiers
+        self.files_found = glob.glob(self.machine_results_dir + '/*.' + self.file_type)
         check_if_filepath_list_is_empty(filepaths=self.files_found,
-                                        error_msg='SIMBA ERROR: Cannot perform time-bin classification analysis, no data in {} directory'.format(self.data_in_dir))
+                                        error_msg=f'SIMBA ERROR: Cannot perform time-bin classification analysis, no data in {self.machine_results_dir} directory')
         print('Processing {} video(s)...'.format(str(len(self.files_found))))
         self.out_df_lst = []
-        self.timer = SimbaTimer()
-        self.timer.start_timer()
 
     def analyze_timebins_clf(self):
         """
@@ -80,12 +66,11 @@ class TimeBinsClf(object):
         None
         """
 
-
         video_dict = {}
         for file_cnt, file_path in enumerate(self.files_found):
             dir_name, file_name, extension = get_fn_ext(file_path)
             data_df = read_df(file_path, self.file_type)
-            video_settings, px_per_mm, fps = read_video_info(self.vid_info_df, file_name)
+            video_settings, px_per_mm, fps = read_video_info(self.video_info_df, file_name)
             fps = int(fps)
             bin_frame_length = self.bin_length * fps
             data_df_lst = [data_df[i:i + bin_frame_length] for i in range(0, data_df.shape[0], bin_frame_length)]
@@ -133,9 +118,7 @@ class TimeBinsClf(object):
         print('SIMBA COMPLETE: Classification time-bins results saved at project_folder/logs/output/{} (elapsed time: {}s)'.format(str('Time_bins_ML_results_' + self.datetime + '.csv'), self.timer.elapsed_time_str))
 
 
-
-
-# test = TimeBinsClf(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals_14bp/project_folder/project_config.ini',
+# test = TimeBinsClf(config_path='/Users/simon/Desktop/envs/troubleshooting/two_black_animals/project_folder/project_config.ini',
 #                    bin_length=2,
 #                    measurements=['First occurance (s)', 'Event count', 'Total event duration (s)', 'Mean event duration (s)'],
 #                    classifiers=['Attack', 'Sniffing'])
