@@ -1,15 +1,13 @@
 __author__ = "Simon Nilsson", "JJ Choong"
 
-import subprocess
-from os import listdir
-from os.path import isfile, join
-import pathlib
-from simba.extract_frames_fast import *
 from tkinter import *
 import platform
 from simba.enums import Defaults
 from tkinter.filedialog import askopenfilename, askdirectory
-
+from simba.utils.lookups import get_icons_paths
+from PIL import ImageTk
+import PIL.Image
+MENU_ICONS = get_icons_paths()
 
 def onMousewheel(event, canvas):
     try:
@@ -101,12 +99,14 @@ class FileSelect(Frame):
         self.lblwidth = lblwidth if lblwidth is not None else 0
         self.parent = parent
         Frame.__init__(self, master=parent, **kw)
+        browse_icon = ImageTk.PhotoImage(image=PIL.Image.open(MENU_ICONS['browse']['icon_path']))
         self.filePath = StringVar()
         self.lblName = Label(self, text=fileDescription, fg=str(self.color), width=str(self.lblwidth), anchor=W)
         self.lblName.grid(row=0, column=0, sticky=W)
         self.entPath = Label(self, textvariable=self.filePath, relief=SUNKEN)
         self.entPath.grid(row=0, column=1)
-        self.btnFind = Button(self, text=Defaults.BROWSE_FILE_BTN_TEXT.value, command=self.setFilePath)
+        self.btnFind = Button(self, text=Defaults.BROWSE_FILE_BTN_TEXT.value, compound='left', image=browse_icon, relief=RAISED, command=self.setFilePath)
+        self.btnFind.image = browse_icon
         self.btnFind.grid(row=0, column=2)
         self.filePath.set(Defaults.NO_FILE_SELECTED_TEXT.value)
 
@@ -155,82 +155,11 @@ class Entry_Box(Frame):
         self.entPath.config(state=setstatus)
 
     def destroy(self):
-        self.lblName.destroy()
-        self.entPath.destroy()
-
-
-# def colorized(filename):
-#
-#     def execute(command):
-#         print(command)
-#         subprocess.call(command, shell=True, stdout = subprocess.PIPE)
-#
-#     ########### DEFINE COMMAND ###########
-#
-#     currentFile = filename
-#     outFile = currentFile.replace('.mp4', '')
-#     outFile = str(outFile) + '_colorized.mp4'
-#     command = (str('python bw2color_video3.py --prototxt colorization_deploy_v2.prototxt --model colorization_release_v2.caffemodel --points pts_in_hull.npy --input ' )+ str(currentFile))
-#     execute(command)
-
-def shortenvideos1(filename, starttime, endtime):
-    if starttime == '' or endtime == '':
-        print('Please enter the time')
-
-    elif filename != '' and filename != 'No file selected':
-
-        def execute(command):
-            subprocess.call(command, shell=True, stdout=subprocess.PIPE)
-
-        ########### DEFINE COMMAND ###########
-
-        currentFile = filename
-        outFile, fileformat = currentFile.split('.')
-        outFile = str(outFile) + '_clipped.mp4'
-        output = os.path.basename(outFile)
-
-        command = (str('ffmpeg -i ') + '"' + str(
-            currentFile) + '"' + ' -ss ' + starttime + ' -to ' + endtime + ' -async 1 ' + '"' + outFile + '"')
-
-        file = pathlib.Path(outFile)
-        if file.exists():
-            print(output, 'already exist')
-        else:
-            print('Clipping video....')
-            execute(command)
-            print(output, ' generated!')
-        return output
-
-
-    else:
-        print('Please select a video to trim')
-
-
-def mergemovebatch(dir, framespersec, vidformat, bit, imgformat):
-    currDir = os.listdir(dir)
-    fps = str(framespersec)
-    fileformat = str('.' + vidformat)
-    bitrate = str(bit)
-    imageformat = str(imgformat)
-
-    for i in currDir:
-        directory = os.path.join(dir, i)
-        fileOut = str(directory) + str(fileformat)
-        currentDirPath = directory
-        currentFileList = [f for f in listdir(currentDirPath) if isfile(join(currentDirPath, f))]
-        imgPath = os.path.join(currentDirPath, currentFileList[0])
-        img = cv2.imread(imgPath)
-        print(imgPath)
-        ffmpegFileName = os.path.join(currentDirPath, '%d.' + str(imageformat))
-        imgShape = img.shape
-        height = imgShape[0]
-        width = imgShape[1]
-        command = str(
-            'ffmpeg -r ' + str(fps) + str(' -f image2 -s ') + str(height) + 'x' + str(width) + ' -i ' + '"' + str(
-                ffmpegFileName) + '"' + ' -vcodec libx264 -b ' + str(bitrate) + 'k ' + '"' + str(fileOut) + '"')
-        print(command)
-        subprocess.call(command, shell=True)
-
+        try:
+            self.lblName.destroy()
+            self.entPath.destroy()
+        except:
+            pass
 
 class FolderSelect(Frame):
     def __init__(self, parent=None, folderDescription="", color=None, title=None, lblwidth=None, **kw):
@@ -239,12 +168,14 @@ class FolderSelect(Frame):
         self.lblwidth = lblwidth if lblwidth is not None else 0
         self.parent = parent
         Frame.__init__(self, master=parent, **kw)
+        browse_icon = ImageTk.PhotoImage(image=PIL.Image.open(MENU_ICONS['browse']['icon_path']))
         self.folderPath = StringVar()
         self.lblName = Label(self, text=folderDescription, fg=str(self.color), width=str(self.lblwidth), anchor=W)
         self.lblName.grid(row=0, column=0, sticky=W)
         self.entPath = Label(self, textvariable=self.folderPath, relief=SUNKEN)
         self.entPath.grid(row=0, column=1)
-        self.btnFind = Button(self, text="Browse Folder", command=self.setFolderPath)
+        self.btnFind = Button(self, text=Defaults.BROWSE_FOLDER_BTN_TEXT.value, compound='left', image=browse_icon, relief=RAISED, command=self.setFolderPath)
+        self.btnFind.image = browse_icon
         self.btnFind.grid(row=0, column=2)
         self.folderPath.set('No folder selected')
 
