@@ -1,9 +1,9 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
-import glob
 import os
 import numpy as np
 import pandas as pd
+from sklearn.inspection import partial_dependence
 from simba.rw_dfs import read_df
 from simba.misc_tools import get_fn_ext
 from imblearn.combine import SMOTEENN
@@ -20,13 +20,18 @@ from yellowbrick.classifier import ClassificationReport
 import shap
 from simba.drop_bp_cords import GenerateMetaDataFileHeaders
 from tabulate import tabulate
-from simba.shap_agg_stats_visualizer import ShapAggregateStatisticsVisualizer
-from simba.read_config_unit_tests import (check_int, check_str,
+from simba.plotting.shap_agg_stats_visualizer import ShapAggregateStatisticsVisualizer
+from simba.read_config_unit_tests import (check_int, check_str, check_if_dir_exists,
                                           check_float,
                                           read_config_entry)
+from concurrent.futures import ThreadPoolExecutor, ProcessPoolExecutor
+from itertools import repeat
 from simba.misc_tools import (create_single_color_lst,
                               SimbaTimer,
-                              detect_bouts)
+                              detect_bouts,
+                              find_core_cnt)
+from simba.utils.errors import ColumnNotFoundError
+from simba.utils.errors import FaultyTrainingSetError
 import configparser
 import platform
 from sklearn.utils import parallel_backend
@@ -34,6 +39,7 @@ import pickle
 from dtreeviz.trees import tree, dtreeviz
 import matplotlib.pyplot as plt
 from simba.enums import ReadConfig, Dtypes, MetaKeys
+import multiprocessing
 plt.switch_backend('agg')
 
 def read_all_files_in_folder(file_paths: list,
@@ -63,7 +69,8 @@ def read_all_files_in_folder(file_paths: list,
     timer = SimbaTimer()
     timer.start_timer()
     df_concat = pd.DataFrame()
-    for file in file_paths:
+    for file_cnt, file in enumerate(file_paths):
+        print(f'Reading in file {str(file_cnt+1)}/{str(len(file_paths))}...')
         _, vid_name, _ = get_fn_ext(file)
         df = read_df(file, file_type).dropna(axis=0, how='all').fillna(0)
         if classifier_names != None:
@@ -617,6 +624,7 @@ def create_shap_log(ini_file_path: str,
                     cnt_present: int,
                     cnt_absent: int,
                     save_path: str,
+                    save_it: int=100,
                     save_file_no=None):
 
     """
@@ -655,6 +663,13 @@ def create_shap_log(ini_file_path: str,
     timer = SimbaTimer()
     timer.start_timer()
     data_df = pd.concat([x_df, y_df], axis=1)
+    if save_file_no == None:
+        out_df_shap_path = os.path.join(save_path, f'SHAP_values_{clf_name}.csv')
+        out_df_raw_path = os.path.join(save_path, f'RAW_SHAP_feature_values_{clf_name}.csv')
+    else:
+        out_df_shap_path = os.path.join(save_path, f'SHAP_values_{str(save_file_no)}_{clf_name}.csv')
+        out_df_raw_path = os.path.join(save_path, f'RAW_SHAP_feature_values_{str(save_file_no)}_{clf_name}.csv')
+
     target_df, nontarget_df = data_df[data_df[y_df.name] == 1], data_df[data_df[y_df.name] == 0]
     if len(target_df) < cnt_present:
         print('SHAP WARNING: Train data contains {} behavior-present annotations. This is less the number of frames you specified to calculate shap values for {}. SimBA will calculate shap scores for the {} behavior-present frames available'.format(str(len(target_df)), str(cnt_present), str(len(target_df))))
@@ -678,15 +693,12 @@ def create_shap_log(ini_file_path: str,
         frame_shap.extend((expected_value, sum(frame_shap), rf_clf.predict_proba(frame_data)[0][1], y_df[cnt]))
         out_df_raw.loc[len(out_df_raw)] = list(shap_df.iloc[frame])
         out_df_shap.loc[len(out_df_shap)] = frame_shap
-        print('SHAP frame: {} / {}'.format(str(cnt+1), str(len(shap_df))))
+        if (cnt % save_it == 0) or (cnt == len(shap_df)-1):
+            print(f'Saving SHAP data after {cnt} iterations...')
+            out_df_shap.to_csv(out_df_shap_path)
+            out_df_raw.to_csv(out_df_raw_path)
+        print('SHAP frame: {} / {}'.format(str(cnt + 1), str(len(shap_df))))
 
-    if save_file_no == None:
-        out_df_shap.to_csv(os.path.join(save_path, 'SHAP_values_' + clf_name + '.csv'))
-        out_df_raw.to_csv(os.path.join(save_path, 'RAW_SHAP_feature_values_' + clf_name + '.csv'))
-
-    else:
-        out_df_shap.to_csv(os.path.join(save_path, 'SHAP_values_' + '_' + str(save_file_no) + clf_name + '.csv'))
-        out_df_raw.to_csv(os.path.join(save_path, 'RAW_SHAP_feature_values_' + '_' + str(save_file_no) + clf_name + '.csv'))
     _ = ShapAggregateStatisticsVisualizer(config_path=ini_file_path,
                                           classifier_name=clf_name,
                                           shap_df=out_df_shap,
@@ -750,7 +762,7 @@ def create_meta_data_csv_training_multiple_models(meta_data,
                                                   save_dir,
                                                   save_file_no=None):
     print('Saving model meta data file...')
-    save_path = os.path.join(save_dir, clf_name + '_' + str(save_file_no) + '_meta.csv')
+    save_path = os.path.join(save_dir,  f'{clf_name}_{str(save_file_no)}_meta.csv')
     out_df = pd.DataFrame.from_dict(meta_data, orient='index').T
     out_df.to_csv(save_path)
 
@@ -947,4 +959,106 @@ def bout_train_test_splitter(x_df: pd.DataFrame,
     y_train = y_df[y_df.index.isin(train_bouts_frames + train_nonbouts_frames)]
     y_test = y_df[y_df.index.isin(test_bouts_frames + test_nonbouts_frames)]
 
-    return x_train, x_test, y_train, y_test
\ No newline at end of file
+    return x_train, x_test, y_train, y_test
+
+def check_dataset_integrity(x_df: pd.DataFrame, y_df: pd.DataFrame):
+    x_df = x_df.replace([np.inf, -np.inf, None], np.nan)
+    x_nan_cnt = x_df.isna().sum()
+    x_nan_cnt = x_nan_cnt[x_nan_cnt > 0]
+
+    if len(x_nan_cnt) > 0:
+        if len(x_nan_cnt) < 10:
+            raise FaultyTrainingSetError(msg=f'{str(len(x_nan_cnt))} feature column(s) exist in some files within the project_folder/csv/targets_inserted directory, but missing in others. ' \
+                  f'SimBA expects all files within the project_folder/csv/targets_inserted directory to have the same number of features: the ' \
+                  f'column names with mismatches are: {list(x_nan_cnt.index)}')
+        else:
+            raise FaultyTrainingSetError(
+                msg=f'{str(len(x_nan_cnt))} feature columns exist in some files, but missing in others. The feature files are found in the project_folder/csv/targets_inserted directory. ' \
+                    f'SimBA expects all files within the project_folder/csv/targets_inserted directory to have the same number of features: the first 10 ' \
+                    f'column names with mismatches are: {list(x_nan_cnt.index)[0:9]}')
+
+    if len(y_df.unique()) == 1:
+        if y_df.unique()[0] == 0:
+            raise FaultyTrainingSetError(msg=f'All training annotations for classifier {str(y_df.name)} is labelled as ABSENT. A classifier has be be trained with both behavior PRESENT and ABSENT ANNOTATIONS.')
+        if y_df.unique()[0] == 1:
+            raise FaultyTrainingSetError(msg=f'All training annotations for classifier {str(y_df.name)} is labelled as PRESENT. A classifier has be be trained with both behavior PRESENT and ABSENT ANNOTATIONS.')
+
+
+def partial_dependence_calculator(clf: RandomForestClassifier,
+                                  x_df: pd.DataFrame,
+                                  clf_name: str,
+                                  save_dir: str,
+                                  clf_cnt: int or None=None):
+
+    print(f'Calculating partial dependencies for {len(x_df.columns)} features...')
+    clf.verbose = 0
+    check_if_dir_exists(save_dir)
+    if clf_cnt:
+        save_dir = os.path.join(save_dir, f'partial_dependencies_{clf_name}_{clf_cnt}')
+    else:
+        save_dir = os.path.join(save_dir, f'partial_dependencies_{clf_name}')
+    if not os.path.exists(save_dir): os.makedirs(save_dir)
+    for feature_cnt, feature_name in enumerate(x_df.columns):
+        save_path = os.path.join(save_dir, f'{feature_name}.csv')
+        pdp, axes = partial_dependence(clf, features=[feature_name], X=x_df, percentiles=(0, 1), grid_resolution=30)
+        df = pd.DataFrame({'partial dependence': pdp[0], 'feature value': axes[0]})
+        df.to_csv(save_path)
+        print(f'Partial dependencies for {feature_name} complete...')
+
+
+def _read_data_file_helper(file_path, file_type, clf_names):
+    """ Private function called by ``simba.train_model_functions.read_all_files_in_folder_mp`` """
+
+    timer = SimbaTimer()
+    timer.start_timer()
+    _, vid_name, _ = get_fn_ext(file_path)
+    df = read_df(file_path, file_type).dropna(axis=0, how='all').fillna(0)
+    if clf_names != None:
+        for clf_name in clf_names:
+            if not clf_name in df.columns:
+                raise ColumnNotFoundError(column_name=clf_name, file_name=file_path)
+    timer.stop_timer()
+    print(f'Reading complete {vid_name} (elapsed time: {timer.elapsed_time_str}s)...')
+    return df
+
+def read_all_files_in_folder_mp(file_paths: list,
+                                file_type: str,
+                                classifier_names: list or None = None):
+    """
+
+    Multiprocessing helper function to read in all data files in a folder to a single
+    pd.DataFrame for downstream ML. Defaults to ceil(CPU COUNT / 2) cores. Asserts that all classifiers
+    have annotation fields present in each dataframe.
+
+    Parameters
+    ----------
+    file_paths: list
+        List of file paths representing files to be read in.
+    file_type: str
+        Type of files in ``file_paths``. OPTIONS: csv or parquet.
+    classifier_names: list or None
+        List of classifier names representing fields of human annotations. If not None, then assert that classifier names
+        are present in each data file.
+
+    Returns
+    -------
+    pd.DataFrame
+
+    """
+    if platform.system() == "Darwin":
+        multiprocessing.set_start_method('spawn', force=True)
+    cpu_cnt, _ = find_core_cnt()
+    df_lst = []
+    with ProcessPoolExecutor(int(np.ceil(cpu_cnt/2))) as pool:
+        for res in pool.map(_read_data_file_helper, file_paths, repeat(file_type), repeat(classifier_names)):
+            df_lst.append(res)
+    df_concat = pd.concat(df_lst, axis=0)
+    if 'scorer' in df_concat.columns:
+        df_concat = df_concat.set_index('scorer')
+    if len(df_concat) == 0:
+        raise ValueError('ANNOTATION ERROR: SimBA found 0 observations (frames) in the project_folder/csv/targets_inserted directory')
+    df_concat = df_concat.loc[:, ~df_concat.columns.str.contains('^Unnamed')]
+
+    return df_concat.reset_index(drop=True)
+
+
