@@ -1,4 +1,4 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
 import os, glob, ast
 from simba.train_model_functions import (read_all_files_in_folder,
@@ -19,7 +19,10 @@ from simba.train_model_functions import (read_all_files_in_folder,
                                          create_x_importance_log,
                                          create_meta_data_csv_training_one_model,
                                          save_rf_model,
-                                         bout_train_test_splitter)
+                                         bout_train_test_splitter,
+                                         check_dataset_integrity,
+                                         partial_dependence_calculator,
+                                         read_all_files_in_folder_mp)
 
 from simba.read_config_unit_tests import (check_int,
                                           check_float,
@@ -89,13 +92,14 @@ class TrainSingleModel(object):
         self.annotation_file_paths = glob.glob(self.data_in_path + '/*.' + self.file_type)
         check_if_filepath_list_is_empty(filepaths=self.annotation_file_paths, error_msg='SIMBA ERROR: Zero annotation files found in project_folder/csv/targets_inserted, cannot create model.')
         print('Reading in {} annotated files...'.format(str(len(self.annotation_file_paths))))
-        self.data_df = read_all_files_in_folder(self.annotation_file_paths, self.file_type, [self.clf_name])
+        self.data_df = read_all_files_in_folder_mp(self.annotation_file_paths, self.file_type, [self.clf_name])
         self.data_df_wo_cords = drop_bp_cords(self.data_df, config_path)
         annotation_cols_to_remove = read_in_all_model_names_to_remove(self.config, self.model_cnt, self.clf_name)
         self.x_y_df = delete_other_annotation_columns(self.data_df_wo_cords, list(annotation_cols_to_remove))
         self.class_names = ['Not_' + self.clf_name, self.clf_name]
         self.x_df, self.y_df = split_df_to_x_y(self.x_y_df, self.clf_name)
         self.feature_names = self.x_df.columns
+        check_dataset_integrity(x_df=self.x_df, y_df=self.y_df)
         print('Number of features in dataset: ' + str(len(self.x_df.columns)))
         print('Number of {} frames in dataset: {} ({}%)'.format(self.clf_name, str(self.y_df.sum()), str(round(self.y_df.sum() / len(self.y_df), 4) * 100)))
         print('Training and evaluating model...')
@@ -158,6 +162,7 @@ class TrainSingleModel(object):
             generate_example_decision_tree_fancy = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.EX_DECISION_TREE_FANCY.value, data_type=Dtypes.STR.value, default_value=False)
             generate_shap_scores = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.SHAP_SCORES.value, data_type=Dtypes.STR.value, default_value=False)
             save_meta_data = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.RF_METADATA.value ,data_type=Dtypes.STR.value, default_value=False)
+            compute_partial_dependency = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.PARTIAL_DEPENDENCY.value, data_type=Dtypes.STR.value, default_value=False)
 
             if self.config.has_option(ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.CLASS_WEIGHTS.value):
                 class_weights = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.CLASS_WEIGHTS.value, data_type=Dtypes.STR.value, default_value=Dtypes.NONE.value)
@@ -179,12 +184,17 @@ class TrainSingleModel(object):
                 shuffle_splits, dataset_splits = Dtypes.NAN.value, Dtypes.NAN.value
             if generate_features_importance_bar_graph in Options.PERFORM_FLAGS.value:
                 feature_importance_bars = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.IMPORTANCE_BARS_N.value, Dtypes.INT.value, Dtypes.NAN.value)
-                check_int(name=ReadConfig.IMPORTANCE_BARS_N.value, value=feature_importance_bars)
+                check_int(name=ReadConfig.IMPORTANCE_BARS_N.value, value=feature_importance_bars, min_value=1)
             else:
                 feature_importance_bars = Dtypes.NAN.value
             if generate_shap_scores in Options.PERFORM_FLAGS.value:
                 shap_target_present_cnt = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.SHAP_PRESENT.value, data_type=Dtypes.INT.value, default_value=0)
                 shap_target_absent_cnt = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.SHAP_ABSENT.value, data_type=Dtypes.INT.value, default_value=0)
+                shap_save_n = read_config_entry(self.config, ReadConfig.CREATE_ENSEMBLE_SETTINGS.value, ReadConfig.SHAP_SAVE_ITERATION.value, data_type=Dtypes.STR.value, default_value=Dtypes.NONE.value)
+                try:
+                    shap_save_n = int(shap_save_n)
+                except ValueError:
+                    shap_save_n = shap_target_present_cnt + shap_target_absent_cnt
                 check_int(name=ReadConfig.SHAP_PRESENT.value, value=shap_target_present_cnt)
                 check_int(name=ReadConfig.SHAP_ABSENT.value, value=shap_target_absent_cnt)
 
@@ -196,6 +206,7 @@ class TrainSingleModel(object):
                                                  verbose=1,
                                                  class_weight=class_weights)
             try:
+                print(f'Fitting {self.clf_name}...')
                 self.rf_clf.fit(self.x_train, self.y_train)
             except Exception as e:
                 print('ERROR: The model contains a faulty array. This may happen when trying to train a model with 0 examples of the behavior of interest')
@@ -212,6 +223,8 @@ class TrainSingleModel(object):
                                     rf_clf=self.rf_clf,
                                     save_dir=self.eval_out_path)
 
+
+
             if generate_precision_recall_curve in Options.PERFORM_FLAGS.value:
                 calc_pr_curve(self.rf_clf, self.x_test, self.y_test, self.clf_name, self.eval_out_path)
             if generate_example_decision_tree in Options.PERFORM_FLAGS.value:
@@ -225,7 +238,19 @@ class TrainSingleModel(object):
             if generate_example_decision_tree_fancy in Options.PERFORM_FLAGS.value:
                 dviz_classification_visualization(self.x_train, self.y_train, self.clf_name, self.class_names, self.eval_out_path)
             if generate_shap_scores in Options.PERFORM_FLAGS.value:
-                create_shap_log(self.ini_path, self.rf_clf, self.x_train, self.y_train, self.feature_names, self.clf_name, shap_target_present_cnt, shap_target_absent_cnt, self.eval_out_path)
+                create_shap_log(ini_file_path=self.ini_path,
+                                rf_clf=self.rf_clf,
+                                x_df=self.x_train,
+                                y_df=self.y_train,
+                                x_names=self.feature_names,
+                                clf_name=self.clf_name,
+                                cnt_present=shap_target_present_cnt,
+                                cnt_absent=shap_target_absent_cnt,
+                                save_it=shap_save_n,
+                                save_path=self.eval_out_path)
+
+            if compute_partial_dependency:
+                partial_dependence_calculator(clf=self.rf_clf, x_df=self.x_train, clf_name=self.clf_name, save_dir=self.eval_out_path)
 
             if save_meta_data in Options.PERFORM_FLAGS.value:
                 meta_data_lst = [self.clf_name, criterion, max_features, min_sample_leaf,
@@ -253,9 +278,12 @@ class TrainSingleModel(object):
         print('Classifier {} saved in models/generated_models directory (elapsed time: {}s).'.format(self.clf_name, self.timer.elapsed_time_str))
         print('Evaluation files are in models/generated_models/model_evaluations folders')
 
-# test = TrainSingleModel(config_path='/Users/simon/Desktop/envs/troubleshooting/Two_animals_16bps/project_folder/project_config.ini')
+# test = TrainSingleModel(config_path='/Users/simon/Desktop/envs/troubleshooting/locomotion/project_folder/project_config.ini')
 # test.perform_sampling()
 # test.train_model()
 # test.save_model()
 
-
+# test = TrainSingleModel(config_path='/Users/simon/Desktop/envs/troubleshooting/naresh/project_folder/project_config.ini')
+# test.perform_sampling()
+# test.train_model()
+# test.save_model()
\ No newline at end of file
