@@ -48,7 +48,7 @@ class ClusterFrequentistCalculator(object):
             pd.DataFrame().to_excel(writer, sheet_name=' ', index=True)
 
     def __one_way_anovas(self):
-        print('Computing ANOVAs...')
+        print('Calculating ANOVAs...')
         self.anova_results = pd.DataFrame(columns=['FEATURE NAME', 'F-STATISTIC', 'P-VALUE'])
         for feature_name in self.data['EMBEDDER']['OUT_FEATURE_NAMES']:
             stats_data = self.feature_data[[feature_name, 'CLUSTER']].sort_values(by=['CLUSTER']).values
@@ -60,7 +60,7 @@ class ClusterFrequentistCalculator(object):
         self.__save_results(df=self.anova_results, name='ANOVA')
 
     def __descriptive_stats(self):
-        print('Computing descriptive statistics..')
+        print('Calculating descriptive statistics..')
         self.descriptive_results = []
         for feature_name in self.data['EMBEDDER']['OUT_FEATURE_NAMES']:
             agg = self.feature_data.groupby(['CLUSTER'])[feature_name].agg(['mean','std', 'sem']).T
@@ -71,7 +71,7 @@ class ClusterFrequentistCalculator(object):
         self.__save_results(df=self.descriptive_results, name='DESCRIPTIVE STATISTICS')
 
     def __tukey_posthoc(self):
-        print('Computing tukey posthocs...')
+        print('Calculating tukey posthocs...')
         self.post_hoc_results = []
         for feature_name in self.data['EMBEDDER']['OUT_FEATURE_NAMES']:
             data = pairwise_tukeyhsd(self.feature_data[feature_name], self.feature_data['CLUSTER'])
@@ -122,12 +122,13 @@ class ClusterXAICalculator(object):
             pd.DataFrame().to_excel(writer, sheet_name=' ', index=True)
 
     def __train_rf_models(self):
-        rf_clf = RandomForestClassifier(n_estimators=20,
-                                             max_features='sqrt',
-                                             n_jobs=-1, criterion='gini',
-                                             min_samples_leaf=1,
-                                             bootstrap=True,
-                                             verbose=1)
+        print('Training ML model...')
+        rf_clf = RandomForestClassifier(n_estimators=100,
+                                        max_features='sqrt',
+                                        n_jobs=-1, criterion='gini',
+                                        min_samples_leaf=1,
+                                        bootstrap=True,
+                                        verbose=1)
         self.rf_data = {}
         for cluster_id in self.feature_data['CLUSTER'].unique():
             self.rf_data[cluster_id] = {}
@@ -142,7 +143,7 @@ class ClusterXAICalculator(object):
 
 
     def __gini_importance(self):
-        print('Computing cluster gini...')
+        print('Calculating cluster gini...')
         for cluster_id, cluster_data in self.rf_data.items():
             importances = list(cluster_data['MODEL'].feature_importances_)
             gini_data = [(feature, round(importance, 6)) for feature, importance in zip(self.data['EMBEDDER']['OUT_FEATURE_NAMES'], importances)]
@@ -150,7 +151,7 @@ class ClusterXAICalculator(object):
             self.__save_results(df=df, name=f'GINI CLUSTER {str(cluster_id)}')
 
     def __permutation_importance(self):
-        print('Computing permutation importance...')
+        print('Calculating permutation importance...')
         for cluster_id, cluster_data in self.rf_data.items():
             p_importances = permutation_importance(cluster_data['MODEL'], cluster_data['X'], cluster_data['Y'], n_repeats=5, random_state=0)
             df = pd.DataFrame(np.column_stack([self.data['EMBEDDER']['OUT_FEATURE_NAMES'], p_importances.importances_mean, p_importances.importances_std]), columns=['FEATURE_NAME', 'FEATURE_IMPORTANCE_MEAN', 'FEATURE_IMPORTANCE_STDEV'])
@@ -162,22 +163,23 @@ class ClusterXAICalculator(object):
             df.to_excel(writer, sheet_name=name, index=True)
 
     def __shap_values(self):
-        if self.settings['shap']['method'] == 'cluster-wise':
-            cluster_combinations = list(itertools.combinations(list(self.rf_data.keys()), 2))
-            for (cluster_one_id, cluster_two_id) in cluster_combinations:
-                explainer = shap.TreeExplainer(self.rf_data[cluster_one_id]['MODEL'], data=None, model_output='raw', feature_perturbation='tree_path_dependent')
-                if self.settings['shap']['sample'] > (len(self.rf_data[cluster_one_id]['X']) or len(self.rf_data[cluster_two_id]['X'])):
-                    self.settings['shap']['sample'] = min(len(self.rf_data[cluster_one_id]['X']), len(self.rf_data[cluster_two_id]['X']))
-                cluster_one_sample = self.rf_data[cluster_one_id]['X'].sample(self.settings['shap']['sample'], replace=False)
-                cluster_two_sample = self.rf_data[cluster_two_id]['X'].sample(self.settings['shap']['sample'], replace=False)
-                cluster_one_shap = pd.DataFrame(explainer.shap_values(cluster_one_sample, check_additivity=False)[1], columns=self.rf_data[cluster_one_id]['X'].columns)
-                cluster_two_shap = pd.DataFrame(explainer.shap_values(cluster_two_sample, check_additivity=False)[1], columns=self.rf_data[cluster_two_id]['X'].columns)
-                mean_df_cluster_one, stdev_df_cluster_one = pd.DataFrame(cluster_one_shap.mean(), columns=['MEAN']), pd.DataFrame(cluster_one_shap.std(), columns=['STDEV'])
-                mean_df_cluster_two, stdev_df_cluster_two = pd.DataFrame(cluster_two_shap.mean(), columns=['MEAN']), pd.DataFrame(cluster_two_shap.std(), columns=['STDEV'])
-                results_cluster_one = mean_df_cluster_one.join(stdev_df_cluster_one).sort_values(by='MEAN', ascending=False)
-                results_cluster_two = mean_df_cluster_two.join(stdev_df_cluster_two).sort_values(by='MEAN', ascending=False)
-                self.__save_results(df=results_cluster_one, name=f'SHAP CLUSTER {str(cluster_one_id)} vs. {str(cluster_two_id)}')
-                self.__save_results(df=results_cluster_two, name=f'SHAP CLUSTER {str(cluster_two_id)} vs. {str(cluster_one_id)}')
+        if self.settings['shap']['run']:
+            if self.settings['shap']['method'] == 'Paired clusters':
+                cluster_combinations = list(itertools.combinations(list(self.rf_data.keys()), 2))
+                for (cluster_one_id, cluster_two_id) in cluster_combinations:
+                    explainer = shap.TreeExplainer(self.rf_data[cluster_one_id]['MODEL'], data=None, model_output='raw', feature_perturbation='tree_path_dependent')
+                    if self.settings['shap']['sample'] > (len(self.rf_data[cluster_one_id]['X']) or len(self.rf_data[cluster_two_id]['X'])):
+                        self.settings['shap']['sample'] = min(len(self.rf_data[cluster_one_id]['X']), len(self.rf_data[cluster_two_id]['X']))
+                    cluster_one_sample = self.rf_data[cluster_one_id]['X'].sample(self.settings['shap']['sample'], replace=False)
+                    cluster_two_sample = self.rf_data[cluster_two_id]['X'].sample(self.settings['shap']['sample'], replace=False)
+                    cluster_one_shap = pd.DataFrame(explainer.shap_values(cluster_one_sample, check_additivity=False)[1], columns=self.rf_data[cluster_one_id]['X'].columns)
+                    cluster_two_shap = pd.DataFrame(explainer.shap_values(cluster_two_sample, check_additivity=False)[1], columns=self.rf_data[cluster_two_id]['X'].columns)
+                    mean_df_cluster_one, stdev_df_cluster_one = pd.DataFrame(cluster_one_shap.mean(), columns=['MEAN']), pd.DataFrame(cluster_one_shap.std(), columns=['STDEV'])
+                    mean_df_cluster_two, stdev_df_cluster_two = pd.DataFrame(cluster_two_shap.mean(), columns=['MEAN']), pd.DataFrame(cluster_two_shap.std(), columns=['STDEV'])
+                    results_cluster_one = mean_df_cluster_one.join(stdev_df_cluster_one).sort_values(by='MEAN', ascending=False)
+                    results_cluster_two = mean_df_cluster_two.join(stdev_df_cluster_two).sort_values(by='MEAN', ascending=False)
+                    self.__save_results(df=results_cluster_one, name=f'SHAP CLUSTER {str(cluster_one_id)} vs. {str(cluster_two_id)}')
+                    self.__save_results(df=results_cluster_two, name=f'SHAP CLUSTER {str(cluster_two_id)} vs. {str(cluster_one_id)}')
 
     def run(self):
         self.__train_rf_models()
@@ -187,6 +189,8 @@ class ClusterXAICalculator(object):
             self.__permutation_importance()
         if self.settings['shap']:
             self.__shap_values()
+        self.timer.stop_timer()
+        print(f'XAI statistics saved (elapsed time {self.timer.elapsed_time_str}s)')
 
 class EmbeddingCorrelationCalculator(object):
     def __init__(self,
