@@ -9,7 +9,7 @@ from simba.unsupervised.misc import bout_aggregator
 from simba.train_model_functions import get_all_clf_names
 from simba.misc_tools import (get_fn_ext,
                               SimbaTimer)
-from simba.features_scripts.unit_tests import read_video_info, read_video_info_csv
+from simba.feature_extractors.unit_tests import read_video_info, read_video_info_csv
 from simba.drop_bp_cords import getBpNames
 from simba.rw_dfs import read_df
 from simba.enums import Paths, ReadConfig, Dtypes
