@@ -5,7 +5,7 @@ from sklearn.preprocessing import (MinMaxScaler,
                                    StandardScaler,
                                    QuantileTransformer)
 from sklearn.feature_selection import VarianceThreshold
-from simba.features_scripts.unit_tests import read_video_info
+from simba.feature_extractors.unit_tests import read_video_info
 from simba.enums import Options
 from simba.misc_tools import detect_bouts
 from joblib import Parallel, delayed
@@ -84,7 +84,6 @@ def find_low_variance_fields(data: pd.DataFrame, variance: float):
 def drop_low_variance_fields(data: pd.DataFrame, fields: list):
     return data.drop(columns=fields)
 
-
 def scaler_transform(data: pd.DataFrame, scaler: object):
     return pd.DataFrame(scaler.transform(data), columns=data.columns)
 
@@ -128,7 +127,8 @@ def bout_aggregator(data: pd.DataFrame,
         return agg_df
 
     output = []
-    for video in data['VIDEO'].unique():
+    for cnt, video in enumerate(data['VIDEO'].unique()):
+        print(f'Processing video {video}...({str(cnt+1)}/{str(len(data["VIDEO"].unique()))})')
         video_df = data[data['VIDEO'] == video].reset_index(drop=True)
         for clf in clfs:
             _, _, fps = read_video_info(vid_info_df=video_info, video_name=video)
