@@ -1,15 +1,12 @@
+import glob
 import os.path
 from tkinter import *
-
 import numpy as np
-
-from simba.tkinter_functions import (hxtScrollbar,
-                                     FolderSelect,
+from simba.tkinter_functions import (FolderSelect,
                                      DropDownMenu,
                                      FileSelect,
                                      Entry_Box)
-from simba.enums import Formats, ReadConfig, Dtypes, Options
-from simba.train_model_functions import get_all_clf_names
+from simba.enums import Formats, Options
 from simba.unsupervised.visualizers import (GridSearchClusterVisualizer,
                                             ClusterVisualizer)
 from simba.unsupervised.data_extractors import DataExtractorMultipleModels
@@ -17,33 +14,29 @@ from simba.unsupervised.umap_embedder import (UMAPGridSearch, UMAPTransform)
 from simba.unsupervised.tsne import TSNEGridSearch
 from simba.unsupervised.hdbscan_clusterer import (HDBSCANClusterer,
                                                   HDBSCANTransform)
-from simba.read_config_unit_tests import (read_config_entry,
-                                          read_config_file,
-                                          check_float,
+from simba.unsupervised.dbcv import DBCVCalculator
+from simba.read_config_unit_tests import (check_float,
                                           check_int,
-                                          check_file_exist_and_readable)
+                                          check_file_exist_and_readable,
+                                          check_if_dir_exists,
+                                          check_if_filepath_list_is_empty)
+from simba.unsupervised.misc import read_pickle
 from simba.unsupervised.cluster_statistics import (ClusterFrequentistCalculator,
                                                    ClusterXAICalculator,
                                                    EmbeddingCorrelationCalculator)
+from simba.mixins.pop_up_mixin import PopUpMixin
 
 
-class GridSearchClusterVisualizerPopUp(object):
+class GridSearchClusterVisualizerPopUp(PopUpMixin):
     def __init__(self,
                  config_path: str):
 
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
+        super().__init__(config_path=config_path, title='DIMENSIONALITY REDUCTION: GRID SEARCH')
+
         self.graph_cnt_options = list(range(1, 11))
         self.scatter_sizes_options = list(range(10, 110, 10))
         self.graph_cnt_options.insert(0, 'None')
-        self.config, self.config_path = read_config_file(config_path), config_path
-        self.model_cnt = read_config_entry(self.config, ReadConfig.SML_SETTINGS.value, ReadConfig.TARGET_CNT.value, data_type=Dtypes.INT.value)
         self.field_types_options = ['START FRAME', 'VIDEO NAMES', 'CLASSIFIER', 'CLASSIFIER PROBABILITY']
-        self.clf_names = get_all_clf_names(config=self.config, target_cnt=self.model_cnt)
-        self.main_frm.wm_title("VISUALIZATION OF CLUSTER GRID SEARCH")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
-
         data_frm = LabelFrame(self.main_frm,text='DATA',font=Formats.LABELFRAME_HEADER_FORMAT.value,padx=5,pady=5,fg='black')
         self.clusterers_dir_select = FolderSelect(data_frm, "CLUSTERERS DIRECTORY:", lblwidth=25)
         self.save_dir_select = FolderSelect(data_frm, "IMAGE SAVE DIRECTORY: ", lblwidth=25)
@@ -56,7 +49,6 @@ class GridSearchClusterVisualizerPopUp(object):
         self.continuous_palette_dropdown = DropDownMenu(settings_frm, 'CONTINUOUS PALETTE:', Options.PALETTE_OPTIONS.value, '25')
         self.continuous_palette_dropdown.setChoices('magma')
 
-
         run_frm = LabelFrame(self.main_frm, text='RUN', font=Formats.LABELFRAME_HEADER_FORMAT.value, padx=5, pady=5, fg='black')
         run_btn = Button(run_frm, text='RUN', fg='blue', command=lambda: self.run())
 
@@ -141,13 +133,9 @@ class GridSearchClusterVisualizerPopUp(object):
         grid_search_visualizer.create_imgs()
 
 
-class BatchDataExtractorPopUp(object):
+class BatchDataExtractorPopUp(PopUpMixin):
     def __init__(self):
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
-        self.main_frm.wm_title("VISUALIZATION OF GRID SEARCH")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
+        super().__init__(title='VISUALIZATION OF GRID SEARCH')
         self.hyperparameter_log_var = BooleanVar(value=True)
 
         data_frm = LabelFrame(self.main_frm, text='DATA', font=Formats.LABELFRAME_HEADER_FORMAT.value, padx=5, pady=5, fg='black')
@@ -195,14 +183,9 @@ class BatchDataExtractorPopUp(object):
                                         clusterer_dir=cluster_dir,
                                         save_dir=save_dir)
 
-class FitDimReductionPopUp(object):
+class FitDimReductionPopUp(PopUpMixin):
     def __init__(self):
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
-        self.main_frm.wm_title("VISUALIZATION OF GRID SEARCH")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
-
+        super().__init__(title='FIT DIMENSIONALITY REDUCTION MODELS')
         self.scaler_options = Options.SCALER_NAMES.value
         self.dim_reduction_algo_options = ['UMAP',
                                            'TSNE']
@@ -245,6 +228,11 @@ class FitDimReductionPopUp(object):
         if float(value) not in list_box_content:
             list_box.insert(0, value)
 
+    def add_defaults_to_listbox(self,
+                                list_box: Listbox,
+                                value: float):
+        list_box.insert(0, value)
+
     def remove_from_listbox(self,
                        list_box: Listbox):
         selection = list_box.curselection()
@@ -276,6 +264,11 @@ class FitDimReductionPopUp(object):
             self.n_neighbors_estimators_listb = Listbox(self.dr_hyperparameters_frm, bg='lightgrey', fg='black', height=5, width=15)
             self.min_distance_listb = Listbox(self.dr_hyperparameters_frm, bg='lightgrey', fg='black', height=5, width=15)
             self.spread_listb = Listbox(self.dr_hyperparameters_frm, bg='lightgrey', fg='black', height=5, width=15)
+
+            self.add_defaults_to_listbox(list_box=self.n_neighbors_estimators_listb, value=15)
+            self.add_defaults_to_listbox(list_box=self.min_distance_listb, value=0.1)
+            self.add_defaults_to_listbox(list_box=self.spread_listb, value=1)
+
             n_neighbors_estimators_lbl.grid(row=1, column=0)
             min_distance_lbl.grid(row=1, column=1)
             spread_lbl.grid(row=1, column=2)
@@ -345,13 +338,9 @@ class FitDimReductionPopUp(object):
             tsne_searcher.fit(hyperparameters=hyperparameters)
 
 
-class TransformDimReductionPopUp(object):
+class TransformDimReductionPopUp(PopUpMixin):
     def __init__(self):
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
-        self.main_frm.wm_title("DIMENSIONALITY REDUCTION: TRANSFORM")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
+        super().__init__(title='DIMENSIONALITY REDUCTION: TRANSFORM')
         self.features_options = ['EXCLUDE', 'INCLUDE: ORIGINAL', 'INCLUDE: SCALED']
 
         self.dim_reduction_frm = LabelFrame(self.main_frm, text='DIMENSIONALITY REDUCTION: TRANSFORM', pady=5, padx=5,font=Formats.LABELFRAME_HEADER_FORMAT.value,fg='black')
@@ -384,16 +373,10 @@ class TransformDimReductionPopUp(object):
                           save_dir=save_dir,
                           settings=settings)
 
-class FitClusterModelsPopUp(object):
+class FitClusterModelsPopUp(PopUpMixin):
     def __init__(self):
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
-        self.main_frm.wm_title("GRID SEARCH CLUSTER MODELS")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
-
+        super().__init__(title='CLUSTERING: GRID SEARCH')
         self.cluster_algo_options = ['HDBSCAN']
-
         self.clustering_frm = LabelFrame(self.main_frm, text='CLUSTERING', pady=5, padx=5,font=Formats.LABELFRAME_HEADER_FORMAT.value,fg='black')
         self.cluster_dataset_frm = LabelFrame(self.clustering_frm, text='DATASET', pady=5, padx=5, font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='black')
         self.dimensionality_reduction_data_selected = FolderSelect(self.cluster_dataset_frm, "EMBEDDING DIRECTORY: ")
@@ -442,6 +425,11 @@ class FitClusterModelsPopUp(object):
             self.min_samples_listb = Listbox(self.cluster_hyperparameters_frm, bg='lightgrey', fg='black', height=5, width=15)
             self.epsilon_listb = Listbox(self.cluster_hyperparameters_frm, bg='lightgrey', fg='black', height=5, width=15)
 
+            self.add_defaults_to_listbox(list_box=self.min_cluster_size_listb, value=15)
+            self.add_defaults_to_listbox(list_box=self.min_samples_listb, value=5)
+            self.add_defaults_to_listbox(list_box=self.epsilon_listb, value=0)
+            self.add_defaults_to_listbox(list_box=self.alpha_listb, value=1)
+
             self.cluster_value_frm.grid(row=3, column=0, sticky=NW)
             self.cluster_value_entry_box.grid(row=0, column=1, sticky=NW)
             self.cluster_hyperparameters_frm.grid(row=4, column=0, sticky=NW)
@@ -480,6 +468,12 @@ class FitClusterModelsPopUp(object):
         if float(value) not in list_box_content:
             list_box.insert(0, value)
 
+    def add_defaults_to_listbox(self,
+                                list_box: Listbox,
+                                value: float):
+        list_box.insert(0, value)
+
+
     def remove_from_listbox(self,
                        list_box: Listbox):
         selection = list_box.curselection()
@@ -502,17 +496,10 @@ class FitClusterModelsPopUp(object):
 
 
 
-class TransformClustererPopUp(object):
+class TransformClustererPopUp(PopUpMixin):
     def __init__(self):
-
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
-        self.main_frm.wm_title("CLUSTERER: TRANSFORM")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
+        super().__init__(title='CLUSTERER: TRANSFORM')
         self.features_options = ['EXCLUDE', 'INCLUDE: ORIGINAL', 'INCLUDE: SCALED']
-
-
         self.transform_clusterer_frm = LabelFrame(self.main_frm, text='CLUSTERER: TRANSFORM', pady=5, padx=5,font=Formats.LABELFRAME_HEADER_FORMAT.value,fg='black')
         self.cluster_model_select = FileSelect(self.transform_clusterer_frm, 'CLUSTER MODEL (PICKLE):', lblwidth=25)
         self.dataset_select = FileSelect(self.transform_clusterer_frm, 'DATASET (PICKLE):',  lblwidth=25)
@@ -541,18 +528,15 @@ class TransformClustererPopUp(object):
                              save_dir=save_dir,
                              settings=settings)
 
-class ClusterVisualizerPopUp(object):
+class ClusterVisualizerPopUp(PopUpMixin):
     def __init__(self,
                  config_path: str):
 
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
+        super().__init__(title='CLUSTER EXAMPLE VISUALIZATIONS')
         self.config_path = config_path
-        self.main_frm.wm_title("CLUSTER EXAMPLE VISUALIZATIONS")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
         self.include_pose_var = BooleanVar(value=True)
         self.speed_options = list(np.arange(0.1, 2.1, 0.1))
+        self.speed_options = [round(x, 1) for x in self.speed_options]
 
         self.data_frm = LabelFrame(self.main_frm, text='DATA', pady=5, padx=5, font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='black')
         self.videos_dir_select = FolderSelect(self.data_frm, "VIDEOS DIRECTORY:", lblwidth=25)
@@ -604,16 +588,11 @@ class ClusterVisualizerPopUp(object):
         cluster_visualizer.create()
 
 
-class ClusterFrequentistStatisticsPopUp(object):
+class ClusterFrequentistStatisticsPopUp(PopUpMixin):
     def __init__(self,
                  config_path: str):
-
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
+        super().__init__(title='CLUSTER FREQUENTIST STATISTICS')
         self.config_path = config_path
-        self.main_frm.wm_title("CLUSTER FREQUENTIST STATISTICS")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
         self.feature_descriptive_stats_var = BooleanVar(value=True)
         self.feature_oneway_anova_var = BooleanVar(value=True)
         self.feature_tukey_var = BooleanVar(value=True)
@@ -659,16 +638,12 @@ class ClusterFrequentistStatisticsPopUp(object):
         descriptive_calculator.run()
 
 
-class ClusterMLStatisticsPopUp(object):
+class ClusterMLStatisticsPopUp(PopUpMixin):
     def __init__(self,
                  config_path: str):
 
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
+        super().__init__(title='CLUSTER XAI STATISTICS')
         self.config_path = config_path
-        self.main_frm.wm_title("CLUSTER XAI STATISTICS")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
         self.gini_importance_var = BooleanVar(value=True)
         self.permutation_importance_var = BooleanVar(value=True)
         self.shap_var = BooleanVar(value=False)
@@ -681,9 +656,11 @@ class ClusterMLStatisticsPopUp(object):
         self.settings_frm = LabelFrame(self.main_frm, text='SETTINGS', pady=5, padx=5, font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='black')
         self.rf_gini_importance_cb = Checkbutton(self.settings_frm, text='CLUSTER RF GINI IMPORTANCE', variable=self.gini_importance_var)
         self.rf_permutation_cb = Checkbutton(self.settings_frm, text='CLUSTER RF PERMUTATION IMPORTANCE', variable=self.permutation_importance_var)
-        self.cluster_shap_cb = Checkbutton(self.settings_frm, text='CLUSTER RF SHAPLEY VALUES', variable=self.shap_var, command= lambda: self.activate_shap_menu)
+        self.cluster_shap_cb = Checkbutton(self.settings_frm, text='CLUSTER RF SHAPLEY VALUES', variable=self.shap_var, command=self.activate_shap_menu)
         self.shap_method_dropdown = DropDownMenu(self.settings_frm, 'SHAP METHOD:', self.shap_method_options, '25')
+        self.shap_method_dropdown.setChoices(self.shap_method_options[0])
         self.shap_sample_dropdown = DropDownMenu(self.settings_frm, 'SHAP SAMPLES:', self.shap_sample_options, '25')
+        self.shap_sample_dropdown.setChoices(self.shap_sample_options[0])
         self.shap_method_dropdown.disable()
         self.shap_sample_dropdown.disable()
 
@@ -712,6 +689,7 @@ class ClusterMLStatisticsPopUp(object):
 
     def run(self):
         clusterer_path = self.clusterer_data.file_path
+        check_file_exist_and_readable(file_path=clusterer_path)
         gini_importance = self.gini_importance_var.get()
         permutation_importance = self.permutation_importance_var.get()
         shap = self.shap_var.get()
@@ -722,20 +700,18 @@ class ClusterMLStatisticsPopUp(object):
         settings = {'gini_importance': gini_importance, 'permutation_importance': permutation_importance,
                     'shap': {'method': shap_method, 'run': shap, 'sample': shap_sample}}
 
-        _ = ClusterXAICalculator(data_path=clusterer_path,
-                                 settings=settings,
-                                 config_path=self.config_path)
+        xai_calculator = ClusterXAICalculator(data_path=clusterer_path,
+                                              settings=settings,
+                                              config_path=self.config_path)
+        xai_calculator.run()
 
 
-class EmbedderCorrelationsPopUp(object):
+class EmbedderCorrelationsPopUp(PopUpMixin):
     def __init__(self,
                  config_path: str):
-        self.main_frm = Toplevel()
-        self.main_frm.minsize(400, 400)
+
+        super().__init__(title='EMBEDDING CORRELATIONS')
         self.config_path = config_path
-        self.main_frm.wm_title("EMBEDDING CORRELATIONS")
-        self.main_frm = hxtScrollbar(self.main_frm)
-        self.main_frm.pack(expand=True, fill=BOTH)
         self.config_path = config_path
         self.correlation_options = ['SPEARMAN', 'PEARSONS', 'KENDALL']
 
@@ -801,6 +777,59 @@ class EmbedderCorrelationsPopUp(object):
                                            settings=settings)
 
 
+class PrintEmBeddingInfoPopUp(PopUpMixin):
+    def __init__(self,
+                 config_path: str):
+        super().__init__(title='PRINT EMBEDDING MODEL INFO')
+        self.config_path = config_path
+        self.data_frm = LabelFrame(self.main_frm, text='DATA', pady=5, padx=5, font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='black')
+        self.dataset_file_selected = FileSelect(self.data_frm, "DATASET (PICKLE): ")
+
+        self.run_frm = LabelFrame(self.main_frm, text='RUN', pady=5, padx=5, font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='black')
+        run_btn = Button(self.run_frm, text='RUN', fg='blue', command=lambda: self.run())
+
+        self.data_frm.grid(row=0, column=0, sticky=NW)
+        self.dataset_file_selected.grid(row=0, column=0, sticky=NW)
+        self.run_frm.grid(row=1, column=0, sticky=NW)
+        run_btn.grid(row=1, column=0, sticky=NW)
+
+    def run(self):
+        check_file_exist_and_readable(file_path=self.dataset_file_selected.file_path)
+        data = read_pickle(data_path=self.dataset_file_selected.file_path)
+        parameters = {**data['PARAMETERS'], **data['EMBEDDER']['PARAMETERS']}
+        print(parameters)
+
+class DBCVPopUp(PopUpMixin):
+    def __init__(self,
+                 config_path: str):
+        super().__init__(title='DENSITY BASED CLUSTER VALIDATION')
+        self.config_path = config_path
+
+        self.data_frm = LabelFrame(self.main_frm, text='DATA', pady=5, padx=5, font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='black')
+        self.folder_selected = FolderSelect(self.data_frm, "DATASET (FOLDER WITH PICKLES): ")
+
+        self.run_frm = LabelFrame(self.main_frm, text='RUN', pady=5, padx=5, font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='black')
+        run_btn = Button(self.run_frm, text='RUN', fg='blue', command=lambda: self.run())
+
+        self.data_frm.grid(row=0, column=0, sticky=NW)
+        self.folder_selected.grid(row=0, column=0, sticky=NW)
+        self.run_frm.grid(row=1, column=0, sticky=NW)
+        run_btn.grid(row=1, column=0, sticky=NW)
+
+    def run(self):
+        check_if_dir_exists(in_dir=self.folder_selected.folder_path)
+        data_paths = glob.glob(self.folder_selected.folder_path + '/*.pickle')
+        check_if_filepath_list_is_empty(filepaths=data_paths, error_msg=f'No pickle files in {self.folder_selected.folder_path}')
+        dbcv_calculator = DBCVCalculator(clusterers_path=self.folder_selected.folder_path, config_path=self.config_path)
+        dbcv_calculator.run()
+
+
+
+
+
+#_ = PrintEmBeddingInfoPopUp(config_path='/Users/simon/Desktop/envs/troubleshooting/Nastacia_unsupervised/project_folder/project_config.ini')
+
+
 
 
 #_ = ClusterFrequentistStatisticsPopUp(config_path='/Users/simon/Desktop/envs/troubleshooting/unsupervised/project_folder/project_config.ini')
