@@ -6,8 +6,12 @@ from simba.tkinter_functions import (hxtScrollbar,
                                      Entry_Box,
                                      DropDownMenu,
                                      FileSelect)
+from PIL import ImageTk
+import PIL.Image
+import os
+from simba.utils.lookups import get_icons_paths
 import tkinter.ttk as ttk
-from simba.enums import Formats, Options
+from simba.enums import Formats
 from simba.enums import ReadConfig, Dtypes
 from simba.train_model_functions import get_all_clf_names
 from simba.unsupervised.dataset_creator import DatasetCreator
@@ -20,7 +24,9 @@ from simba.unsupervised.pop_up_classes import (GridSearchClusterVisualizerPopUp,
                                                ClusterVisualizerPopUp,
                                                ClusterFrequentistStatisticsPopUp,
                                                ClusterMLStatisticsPopUp,
-                                               EmbedderCorrelationsPopUp)
+                                               EmbedderCorrelationsPopUp,
+                                               PrintEmBeddingInfoPopUp,
+                                               DBCVPopUp)
 
 class UnsupervisedGUI(object):
     def __init__(self,
@@ -29,7 +35,7 @@ class UnsupervisedGUI(object):
         self.config, self.config_path = read_config_file(config_path), config_path
         self.project_path, self.file_type = read_project_path_and_file_type(config=self.config)
         self.main = Toplevel()
-        self.main.minsize(900, 800)
+        self.main.minsize(1000, 800)
         self.main.wm_title("UNSUPERVISED ANALYSIS")
         self.main.columnconfigure(0, weight=1)
         self.main.rowconfigure(0, weight=1)
@@ -42,6 +48,9 @@ class UnsupervisedGUI(object):
         self.clf_slice_options = [f'ALL CLASSIFIERS ({str(len(self.clf_names))})']
         for clf_name in self.clf_names:
             self.clf_slice_options.append(f'{clf_name}')
+        self.btn_icons = get_icons_paths()
+        for k in self.btn_icons.keys():
+            self.btn_icons[k]['img'] = ImageTk.PhotoImage(image=PIL.Image.open(os.path.join(os.path.dirname('__file__'), self.btn_icons[k]['icon_path'])))
 
         self.bout_aggregation_options = ['MEAN', 'MEDIAN']
         self.main = ttk.Notebook(hxtScrollbar(self.main))
@@ -50,11 +59,11 @@ class UnsupervisedGUI(object):
         self.clustering_tab = ttk.Frame(self.main)
         self.visualization_tab = ttk.Frame(self.main)
         self.metrics_tab = ttk.Frame(self.main)
-        self.main.add(self.create_dataset_tab, text=f'{"[CREATE DATASET]": ^20s}')
-        self.main.add(self.dimensionality_reduction_tab, text=f'{"[DIMENSIONALITY REDUCTION]": ^20s}')
-        self.main.add(self.clustering_tab, text=f'{"[CLUSTERING]": ^20s}')
-        self.main.add(self.visualization_tab, text=f'{"[VISUALIZATION]": ^20s}')
-        self.main.add(self.metrics_tab, text=f'{"[METRICS]": ^20s}')
+        self.main.add(self.create_dataset_tab, text=f'{"[CREATE DATASET]": ^20s}', compound='left', image=self.btn_icons['features']['img'])
+        self.main.add(self.dimensionality_reduction_tab, text=f'{"[DIMENSIONALITY REDUCTION]": ^20s}', compound='left', image=self.btn_icons['dimensionality_reduction']['img'])
+        self.main.add(self.clustering_tab, text=f'{"[CLUSTERING]": ^20s}', compound='left', image=self.btn_icons['cluster']['img'])
+        self.main.add(self.visualization_tab, text=f'{"[VISUALIZATION]": ^20s}', compound='left', image=self.btn_icons['visualize']['img'])
+        self.main.add(self.metrics_tab, text=f'{"[METRICS]": ^20s}', compound='left', image=self.btn_icons['metrics']['img'])
         self.main.grid(row=0)
 
         create_dataset_frm = LabelFrame(self.create_dataset_tab, text='CREATE DATASET', pady=5, padx=5,font=Formats.LABELFRAME_HEADER_FORMAT.value,fg='black')
@@ -102,11 +111,12 @@ class UnsupervisedGUI(object):
         self.cluster_visualizer.grid(row=1, column=0, sticky='NW')
 
         self.metrics_frm = LabelFrame(self.metrics_tab, text='METRICS', pady=5, padx=5, font=Formats.LABELFRAME_HEADER_FORMAT.value, fg='black')
-        self.dbcv_btn = Button(self.metrics_frm, text='DENSITY-BASED CLUSTER VALIDATION', fg='blue', command=lambda: None)
+        self.dbcv_btn = Button(self.metrics_frm, text='DENSITY-BASED CLUSTER VALIDATION', fg='blue', command=lambda: DBCVPopUp(config_path=self.config_path))
         self.extract_single_metrics_btn = Button(self.metrics_frm, text='EXTRACT UNSUPERVISED RESULTS (MULTIPLE MODELS)', fg='red', command=lambda: BatchDataExtractorPopUp())
         self.cluster_descriptives_btn = Button(self.metrics_frm, text='CLUSTER FREQUENTIST STATISTICS', fg='green', command=lambda: ClusterFrequentistStatisticsPopUp(config_path=self.config_path))
         self.cluster_xai_btn = Button(self.metrics_frm, text='CLUSTER XAI STATISTICS', fg='blue', command=lambda: ClusterMLStatisticsPopUp(config_path=self.config_path))
         self.embedding_corr_btn = Button(self.metrics_frm, text='EMBEDDING CORRELATIONS', fg='orange', command=lambda: EmbedderCorrelationsPopUp(config_path=self.config_path))
+        self.print_embedding_info_btn = Button(self.metrics_frm, text='PRINT MODEL INFO', fg='black', command=lambda: PrintEmBeddingInfoPopUp(config_path=self.config_path))
 
         self.metrics_frm.grid(row=0, column=0, sticky='NW')
         self.dbcv_btn.grid(row=0, column=0, sticky='NW')
@@ -114,6 +124,7 @@ class UnsupervisedGUI(object):
         self.cluster_descriptives_btn.grid(row=2, column=0, sticky='NW')
         self.cluster_xai_btn.grid(row=3, column=0, sticky='NW')
         self.embedding_corr_btn.grid(row=4, column=0, sticky='NW')
+        self.print_embedding_info_btn.grid(row=5, column=0, sticky='NW')
 
         self.main.mainloop()
 
@@ -141,4 +152,4 @@ class UnsupervisedGUI(object):
     def launch_grid_search_visualization_pop_up(self):
         _ = GridSearchClusterVisualizerPopUp(config_path=self.config_path)
 
-_ = UnsupervisedGUI(config_path='/Users/simon/Desktop/envs/troubleshooting/unsupervised/project_folder/project_config.ini')
\ No newline at end of file
+# _ = UnsupervisedGUI(config_path='/Users/simon/Desktop/envs/troubleshooting/Nastacia_unsupervised/project_folder/project_config.ini')
\ No newline at end of file
