@@ -1,3 +1,5 @@
+__author__ = "Simon Nilsson"
+
 import glob, os
 from simba.read_config_unit_tests import (check_file_exist_and_readable,
                                           check_int)
@@ -6,10 +8,14 @@ import cv2
 from pathlib import Path
 from PIL import Image
 from simba.extract_frames_fast import video_to_frames
-from simba.enums import Formats, Paths
+from simba.enums import Formats
 import re
 import subprocess
 import simba
+from simba.utils.errors import (NotDirectoryError,
+                                NoFilesFoundError,
+                                FileExistError,
+                                CountError)
 
 
 
@@ -38,12 +44,10 @@ def change_img_format(directory: str,
 
     """
     if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError
+        raise NotDirectoryError('SIMBA ERROR: {} is not a valid directory'.format(directory))
     files_found = glob.glob(directory + '/*.{}'.format(file_type_in))
     if len(files_found) < 1:
-        print('SIMBA ERROR: No {} files (with .{} file ending) found in the {} directory'.format(file_type_in, file_type_in, directory))
-        raise ValueError
+        raise NoFilesFoundError('SIMBA ERROR: No {} files (with .{} file ending) found in the {} directory'.format(file_type_in, file_type_in, directory))
     print('{} image files found in {}...'.format(str(len(files_found)), directory))
     for file_path in files_found:
         im = Image.open(file_path)
@@ -185,8 +189,7 @@ def change_fps_of_multiple_videos(directory: str,
     """
 
     if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError()
+        raise NotDirectoryError(msg='SIMBA ERROR: {} is not a valid directory'.format(directory))
     check_int(name='New fps', value=fps)
     video_paths = []
     file_paths_in_folder = [f for f in glob.glob(directory + '/*') if os.path.isfile(f)]
@@ -195,8 +198,7 @@ def change_fps_of_multiple_videos(directory: str,
         if ext.lower() in ['.avi', '.mp4', '.mov', '.flv']:
             video_paths.append(file_path)
     if len(video_paths) < 1:
-        print('SIMBA ERROR: No files with .mp4, .avi, .mov, .flv file ending found in the {} directory'.format(directory))
-        raise ValueError()
+        raise NoFilesFoundError(msg='SIMBA ERROR: No files with .mp4, .avi, .mov, .flv file ending found in the {} directory'.format(directory))
     for file_cnt, file_path in enumerate(video_paths):
         dir_name, file_name, ext = get_fn_ext(filepath=file_path)
         print('Converting FPS for {}...'.format(file_name))
@@ -223,8 +225,7 @@ def convert_video_powerpoint_compatible_format(file_path: str):
     dir, file_name, ext = get_fn_ext(filepath=file_path)
     save_name = os.path.join(dir, file_name + '_powerpointready.mp4')
     if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
+        raise FileExistError(msg='SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
     command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' -c:v libx264 -preset slow  -profile:v high -level:v 4.0 -pix_fmt yuv420p -crf 22 -codec:a aac ' + '"' + save_name + '"')
     print('Creating video in powerpoint compatible format... ')
     subprocess.call(command, shell=True, stdout=subprocess.PIPE)
@@ -246,8 +247,7 @@ def convert_to_mp4(file_path: str):
     dir, file_name, ext = get_fn_ext(filepath=file_path)
     save_name = os.path.join(dir, file_name + '_converted.mp4')
     if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
+        raise FileExistError(msg='SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
     command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' ' + '"' + save_name + '"')
     print('Converting to mp4... ')
     subprocess.call(command, shell=True, stdout=subprocess.PIPE)
@@ -270,8 +270,7 @@ def video_to_greyscale(file_path: str):
     dir, file_name, ext = get_fn_ext(filepath=file_path)
     save_name = os.path.join(dir, file_name + '_grayscale.mp4')
     if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
+        raise FileExistError(msg='SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
     command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' -vf format=gray ' + '"' + save_name + '"')
     print('Converting to greyscale... ')
     subprocess.call(command, shell=True, stdout=subprocess.PIPE)
@@ -325,8 +324,7 @@ def remove_beginning_of_video(file_path: str,
     dir, file_name, ext = get_fn_ext(filepath=file_path)
     save_name = os.path.join(dir, file_name + '_shorten.mp4')
     if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
+        raise FileExistError(msg='SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
     command = (str('ffmpeg -ss ') + str(int(time)) + ' -i ' + '"' + str(file_path) + '"' + ' -c:v libx264 -c:a aac ' + '"' + save_name + '"')
     print('Shortening video... ')
     subprocess.call(command, shell=True, stdout=subprocess.PIPE)
@@ -355,8 +353,7 @@ def clip_video_in_range(file_path: str,
     dir, file_name, ext = get_fn_ext(filepath=file_path)
     save_name = os.path.join(dir, file_name + '_clipped.mp4')
     if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
+        raise FileExistError(msg='SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
     command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' -ss ' + str(start_time) + ' -to ' + str(end_time) + ' -async 1 ' + '"' + save_name + '"')
     print('Clipping video... ')
     subprocess.call(command, shell=True, stdout=subprocess.PIPE)
@@ -385,8 +382,7 @@ def downsample_video(file_path: str,
     dir, file_name, ext = get_fn_ext(filepath=file_path)
     save_name = os.path.join(dir, file_name + '_downsampled.mp4')
     if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
+        raise FileExistError('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
     command = (str('ffmpeg -i ') + '"' + str(file_path) + '"' + ' -vf scale=' + str(video_width) + ':' + str(video_height) + ' ' + '"' + save_name + '"' + ' -hide_banner')
     print('Down-sampling video... ')
     subprocess.call(command, shell=True, stdout=subprocess.PIPE)
@@ -422,8 +418,7 @@ def gif_creator(file_path: str,
     dir, file_name, ext = get_fn_ext(filepath=file_path)
     save_name = os.path.join(dir, file_name + '.gif')
     if os.path.isfile(save_name):
-        print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
-        raise FileExistsError()
+        raise FileExistError('SIMBA ERROR: The outfile file already exist: {}.'.format(save_name))
     command = 'ffmpeg -ss ' + str(start_time) + ' -t ' + str(duration) + ' -i ' + '"' + str(file_path) + '"' + ' -filter_complex "[0:v] fps=15,scale=w=' + str(width) + ':h=-1,split [a][b];[a] palettegen=stats_mode=single [p];[b][p] paletteuse=new=1" ' + '"' + str(save_name) + '"'
     print('Creating gif sample... ')
     subprocess.call(command, shell=True, stdout=subprocess.PIPE)
@@ -449,8 +444,7 @@ def batch_convert_video_format(directory: str,
     """
 
     if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError()
+        raise NotDirectoryError(msg='SIMBA ERROR: {} is not a valid directory'.format(directory))
     video_paths = []
     file_paths_in_folder = [f for f in glob.glob(directory + '/*') if os.path.isfile(f)]
     for file_path in file_paths_in_folder:
@@ -458,15 +452,13 @@ def batch_convert_video_format(directory: str,
         if ext.lower() == '.{}'.format(input_format.lower()):
             video_paths.append(file_path)
     if len(video_paths) < 1:
-        print('SIMBA ERROR: No files with .{} file ending found in the {} directory'.format(input_format, directory))
-        raise ValueError()
+        raise NoFilesFoundError(msg='SIMBA ERROR: No files with .{} file ending found in the {} directory'.format(input_format, directory))
     for file_cnt, file_path in enumerate(video_paths):
         dir_name, file_name, ext = get_fn_ext(filepath=file_path)
         print('Processing video {}...'.format(file_name))
         save_path = os.path.join(dir_name, file_name + '.{}'.format(output_format.lower()))
         if os.path.isfile(save_path):
-            print('SIMBA ERROR: The outfile file already exist: {}.'.format(save_path))
-            raise FileExistsError()
+            raise FileExistError(msg='SIMBA ERROR: The outfile file already exist: {}.'.format(save_path))
         command = 'ffmpeg -y -i ' + '"' + file_path + '"' + ' -c:v libx264 -crf 5 -preset medium -c:a libmp3lame -b:a 320k '+'"' + save_path + '"'
         subprocess.call(command, shell=True, stdout=subprocess.PIPE)
         print('Video {} complete, (Video {}/{})...'.format(file_name, str(file_cnt+1), str(len(video_paths))))
@@ -485,8 +477,7 @@ def batch_create_frames(directory: str):
     """
 
     if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError()
+        raise NotDirectoryError(msg='SIMBA ERROR: {} is not a valid directory'.format(directory))
     video_paths = []
     file_paths_in_folder = [f for f in glob.glob(directory + '/*') if os.path.isfile(f)]
     for file_path in file_paths_in_folder:
@@ -494,8 +485,7 @@ def batch_create_frames(directory: str):
         if ext.lower() in ['.avi', '.mp4', '.mov', '.flv']:
             video_paths.append(file_path)
     if len(video_paths) < 1:
-        print('SIMBA ERROR: No files with .mp4, .avi, .mov, .flv file ending found in the {} directory'.format(directory))
-        raise ValueError()
+        raise NoFilesFoundError(msg='SIMBA ERROR: No files with .mp4, .avi, .mov, .flv file ending found in the {} directory'.format(directory))
     for file_cnt, file_path in enumerate(video_paths):
         dir_name, file_name, ext = get_fn_ext(filepath=file_path)
         print('Processing video {}...'.format(file_name))
@@ -604,12 +594,10 @@ def crop_single_video(file_path: str):
     cv2.waitKey(0)
     cv2.destroyAllWindows()
     if (width == 0 and height == 0) or (width + height + top_lext_x + top_left_y == 0):
-        print('CROP FAILED: Cropping height and width are both 0. Please try again.')
-        raise ValueError()
+        raise CountError(msg='CROP FAILED: Cropping height and width are both 0. Please try again.')
     save_path = os.path.join(dir_name, file_name + '_cropped.mp4')
     if os.path.isfile(save_path):
-        print('SIMBA ERROR: The out file file already exist: {}.'.format(save_path))
-        raise FileExistsError()
+        raise FileExistError(msg='SIMBA ERROR: The out file file already exist: {}.'.format(save_path))
     command = str('ffmpeg -y -i ') + '"' + str(file_path) + '"' + str(' -vf ') + str('"crop=') + str(width) + ':' + str(height) + ':' + str(top_lext_x) + ':' + str(top_left_y) + '" ' + str('-c:v libx264 -crf 21 -c:a copy ') + '"' + str(save_path) + '"'
     subprocess.call(command, shell=True)
     print('SIMBA COMPLETE: Video {} cropped and saved at {}'.format(file_name, save_path))
@@ -629,8 +617,7 @@ def crop_multiple_videos(directory_path: str,
     """
 
     if not os.path.isdir(directory_path):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory_path))
-        raise NotADirectoryError()
+        raise NotDirectoryError(msg='SIMBA ERROR: {} is not a valid directory'.format(directory_path))
     video_paths = []
     file_paths_in_folder = [f for f in glob.glob(directory_path + '/*') if os.path.isfile(f)]
     for file_path in file_paths_in_folder:
@@ -638,8 +625,7 @@ def crop_multiple_videos(directory_path: str,
         if ext.lower() in ['.avi', '.mp4', '.mov', '.flv']:
             video_paths.append(file_path)
     if len(video_paths) < 1:
-        print('SIMBA ERROR: No files with .mp4, .avi, .mov, .flv file ending found in the {} directory'.format(directory))
-        raise ValueError()
+        raise NoFilesFoundError(msg='SIMBA ERROR: No files with .mp4, .avi, .mov, .flv file ending found in the {} directory'.format(directory_path))
     cap = cv2.VideoCapture(file_paths_in_folder[0])
     cap.set(1, 0)
     ret, frame = cap.read()
@@ -651,8 +637,7 @@ def crop_multiple_videos(directory_path: str,
     cv2.waitKey(0)
     cv2.destroyAllWindows()
     if (width == 0 and height == 0) or (width + height + top_lext_x + top_left_y == 0):
-        print('CROP FAILED: Cropping height and width are both 0. Please try again.')
-        raise ValueError()
+        raise CountError(msg='CROP FAILED: Cropping height and width are both 0. Please try again.')
     for file_cnt, file_path in enumerate(video_paths):
         dir_name, file_name, ext = get_fn_ext(filepath=file_path)
         print('Cropping video {}...'.format(file_name))
@@ -688,15 +673,13 @@ def frames_to_movie(directory: str,
 
 
     if not os.path.isdir(directory):
-        print('SIMBA ERROR: {} is not a valid directory'.format(directory))
-        raise NotADirectoryError()
+        raise NotDirectoryError(msg='SIMBA ERROR: {} is not a valid directory'.format(directory))
     check_int(name='FPS', value=fps)
     check_int(name='BITRATE', value=bitrate)
     file_paths_in_folder = [f for f in glob.glob(directory + '/*') if os.path.isfile(f)]
     img_paths_in_folder = [x for x in file_paths_in_folder if Path(x).suffix[1:] == img_format]
     if len(img_paths_in_folder) < 1:
-        print('SIMBA ERROR: Zero images of file-type {} found in {} directory'.format(img_format, directory))
-        raise ValueError()
+        raise NoFilesFoundError(msg='SIMBA ERROR: Zero images of file-type {} found in {} directory'.format(img_format, directory))
     img = cv2.imread(img_paths_in_folder[0])
     img_h, img_w = int(img.shape[0]), int(img.shape[1])
     ffmpeg_fn = os.path.join(directory, '%d.{}'.format(img_format))
